@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2013 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: March 2013 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains debugging functions. */
@@ -15,26 +15,26 @@
 #include "outhdr.h"
 
 
-static char *fontnames[] = {
+static const char *fontnames[] = {
   "roman", "italic", "bold", "bolditalic", "symbol", "mu", "mf",
   "extra 1", "extra 2", "extra 3", "extra 4",
   "extra 5", "extra 6", "extra 7", "extra 8" };
 
-static char *clefstrings[] = {
+static const char *clefstrings[] = {
   "Treble", "Soprano", "Mezzo", "Alto", "Tenor", "Bass",
   "Trebledescant", "Trebletenor", "Soprabass", "Contrabass", "None",
   "TrebletenorB", "Hclef" };
 
-static char *nhstrings[] = {
+static const char *nhstrings[] = {
   "normal", "cross", "harmonic", "none", "only" };
 
-static char *ntstrings[] = {
+static const char *ntstrings[] = {
   "B   ", "SB  ", "M   ", "c   ", "q   ", "sq  ", "dsq ", "hdsq" };
 
-static char *accstrings[] = {
+static const char *accstrings[] = {
   "  ", "##", "$ ", "$$", "% ", "# " };
 
-static char *ornstrings[] = {
+static const char *ornstrings[] = {
   "fermata", "trill", "trill+sharp", "trill+flat", "trill+natural",
   "tremolo1", "tremolo2", "tremolo3", "mordent", "double mordent",
   "inverted mordent", "double inverted mordent", "turn", 
@@ -58,7 +58,7 @@ Returns:    nothing
 */
 
 void
-debug_printf(char *format, ...)
+debug_printf(const char *format, ...)
 {
 uschar buff[256];
 va_list ap;
@@ -478,7 +478,7 @@ if (p == NULL) debug_printf("Empty bar\n\n"); else
       case b_text:
         {
         b_textstr *pp = (b_textstr *)p;
-        uschar *s = pp->string;
+        uschar *ss = pp->string;
         int flags = pp->flags;
         BOOL absolute = (flags & text_absolute) != 0;
 
@@ -486,10 +486,9 @@ if (p == NULL) debug_printf("Empty bar\n\n"); else
         if ((flags & text_ul) != 0)
           {
           int i;
-          uschar *s = pp->string;
-          for (i = 0; i < pp->ulen; i++) debug_printf("%c", *s++);
+          for (i = 0; i < pp->ulen; i++) debug_printf("%c", *ss++);
           }
-        else debug_printf("%s", s);
+        else debug_printf("%s", ss);
         debug_printf("\"");
 
         if ((flags & text_fb) != 0) debug_printf("/fb");
