@@ -2,11 +2,11 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2009 */
+/* Copyright (c) Philip Hazel, 1991 - 2013 */
 
 /* Written by Philip Hazel, starting November 1991 */
 /* Re-coded for Unicode support: August 2005 */
-/* This file last modified: January 2009 */
+/* This file last modified: December 2013 */
 
 
 /* This file contains code for handling text fonts */
@@ -45,52 +45,66 @@ static an2uencod an2ulist[] = {
   { US"C",               0x0043, -1 },
   { US"Cacute",          0x0106, -1 },
   { US"Ccaron",          0x010c, -1 },
-  { US"Ccedilla",        0x00c6, -1 },
+  { US"Ccedilla",        0x00c7, -1 },
+  { US"Ccircumflex",     0x0108, -1 },
+  { US"Cdotaccent",      0x010a, -1 },
   { US"D",               0x0044, -1 },
   { US"Dcaron",          0x010e, -1 },
   { US"Dcroat",          0x0110, -1 },
   { US"Delta",           0x0394, +0 },
   { US"E",               0x0045, -1 },
   { US"Eacute",          0x00c9, -1 },
+  { US"Ebreve",          0x0114, -1 },
   { US"Ecaron",          0x011a, -1 },
   { US"Ecircumflex",     0x00ca, -1 },
   { US"Edieresis",       0x00cb, -1 },
   { US"Edotaccent",      0x0116, -1 },
   { US"Egrave",          0x00c8, -1 },
   { US"Emacron",         0x0112, -1 },
+  { US"Eng",             0x014a, -1 },
   { US"Eogonek",         0x0118, -1 },
   { US"Eth",             0x00d0, -1 },
   { US"Euro",            0x20ac, +1 },
   { US"F",               0x0046, -1 },
   { US"G",               0x0047, -1 },
   { US"Gbreve",          0x011e, -1 },
+  { US"Gcircumflex",     0x011c, -1 },
   { US"Gcommaaccent",    0x0122, -1 },
+  { US"Gdotaccent",      0x0120, -1 },
   { US"H",               0x0048, -1 },
+  { US"Hbar",            0x0126, -1 },
+  { US"Hcircumflex",     0x0124, -1 },
   { US"I",               0x0049, -1 },
+  { US"IJ",              0x0132, -1 },
   { US"Iacute",          0x00cd, -1 },
+  { US"Ibreve",          0x012c, -1 },
   { US"Icircumflex",     0x00ce, -1 },
   { US"Idieresis",       0x00cf, -1 },
   { US"Idotaccent",      0x0130, -1 },
   { US"Igrave",          0x00cc, -1 },
   { US"Imacron",         0x012a, -1 },
   { US"Iogonek",         0x012e, -1 },
+  { US"Itilde",          0x0128, -1 },
   { US"J",               0x004a, -1 },
+  { US"Jcircumflex",     0x0134, -1 },
   { US"K",               0x004b, -1 },
   { US"Kcommaaccent",    0x0136, -1 },
   { US"L",               0x004c, -1 },
   { US"Lacute",          0x0139, -1 },
   { US"Lcaron",          0x013d, -1 },
   { US"Lcommaaccent",    0x013b, -1 },
+  { US"Ldot",            0x013f, -1 },
   { US"Lslash",          0x0141, -1 },
   { US"M",               0x004d, -1 },
   { US"N",               0x004e, -1 },
   { US"Nacute",          0x0143, -1 },
   { US"Ncaron",          0x0147, -1 },
-  { US"Ncommaaccent",    0x0147, -1 },
+  { US"Ncommaaccent",    0x0145, -1 },
   { US"Ntilde",          0x00d1, -1 },
   { US"O",               0x004f, -1 },
   { US"OE",              0x0152, -1 },
   { US"Oacute",          0x00d3, -1 },
+  { US"Obreve",          0x014e, -1 },
   { US"Ocircumflex",     0x00d4, -1 },
   { US"Odieresis",       0x00d6, -1 },
   { US"Ograve",          0x00d2, -1 },
@@ -108,13 +122,17 @@ static an2uencod an2ulist[] = {
   { US"Sacute",          0x015a, -1 },
   { US"Scaron",          0x0160, -1 },
   { US"Scedilla",        0x015e, -1 },
+  { US"Scircumflex",     0x015c, -1 },
   { US"Scommaaccent",    0x0218, +2 },
   { US"T",               0x0054, -1 },
+  { US"Tbar",            0x0166, -1 },
   { US"Tcaron",          0x0164, -1 },
+  { US"Tcedilla",        0x0162, -1 },
   { US"Tcommaaccent",    0x021a, +3 },
   { US"Thorn",           0x00de, -1 },
   { US"U",               0x0055, -1 },
   { US"Uacute",          0x00da, -1 },
+  { US"Ubreve",          0x016c, -1 },
   { US"Ucircumflex",     0x00db, -1 },
   { US"Udieresis",       0x00dc, -1 },
   { US"Ugrave",          0x00d9, -1 },
@@ -122,11 +140,14 @@ static an2uencod an2ulist[] = {
   { US"Umacron",         0x016a, -1 },
   { US"Uogonek",         0x0172, -1 },
   { US"Uring",           0x016e, -1 },
+  { US"Utilde",          0x0168, -1 },
   { US"V",               0x0056, -1 },
   { US"W",               0x0057, -1 },
+  { US"Wcircumflex",     0x0174, -1 },
   { US"X",               0x0058, -1 },
   { US"Y",               0x0059, -1 },
   { US"Yacute",          0x00dd, -1 },
+  { US"Ycircumflex",     0x0176, -1 },
   { US"Ydieresis",       0x0178, -1 },
   { US"Z",               0x005a, -1 },
   { US"Zacute",          0x0179, -1 },
@@ -164,6 +185,8 @@ static an2uencod an2ulist[] = {
   { US"caron",           0x030c, +5 },
   { US"ccaron",          0x010d, -1 },
   { US"ccedilla",        0x00e7, -1 },
+  { US"ccircumflex",     0x0109, -1 },
+  { US"cdotaccent",      0x010b, -1 },
   { US"cedilla",         0x00b8, -1 },
   { US"cent",            0x00a2, -1 },
   { US"circumflex",      0x0302, +6 },
@@ -185,6 +208,7 @@ static an2uencod an2ulist[] = {
   { US"dotlessi",        0x0131, -1 },
   { US"e",               0x0065, -1 },
   { US"eacute",          0x00e9, -1 },
+  { US"ebreve",          0x0115, -1 },
   { US"ecaron",          0x011b, -1 },
   { US"ecircumflex",     0x00ea, -1 },
   { US"edieresis",       0x00eb, -1 },
@@ -195,6 +219,7 @@ static an2uencod an2ulist[] = {
   { US"emacron",         0x0113, -1 },
   { US"emdash",          0x2014, 12 },
   { US"endash",          0x2013, 13 },
+  { US"eng",             0x014b, -1 },
   { US"eogonek",         0x0119, -1 },
   { US"equal",           0x003d, -1 },
   { US"eth",             0x00f0, -1 },
@@ -209,7 +234,9 @@ static an2uencod an2ulist[] = {
   { US"fraction",        0x2044, 17 },
   { US"g",               0x0067, -1 },
   { US"gbreve",          0x011f, -1 },
+  { US"gcircumflex",     0x011d, -1 },
   { US"gcommaaccent",    0x0123, -1 },
+  { US"gdotaccent",      0x0121, -1 },
   { US"germandbls",      0x00df, -1 },
   { US"grave",           0x0060, -1 },
   { US"greater",         0x003e, -1 },
@@ -219,27 +246,37 @@ static an2uencod an2ulist[] = {
   { US"guilsinglleft",   0x2039, 19 },
   { US"guilsinglright",  0x203a, 20 },
   { US"h",               0x0068, -1 },
+  { US"hbar",            0x0127, -1 },
+  { US"hcircumflex",     0x0125, -1 },
   { US"hungarumlaut",    0x030b, 21 },
   /* 002d is "hyphen-minus"; Unicode also has separate codes for hyphen and
   for minus. We use the latter below. */
   { US"hyphen",          0x002d, -1 },
   { US"i",               0x0069, -1 },
   { US"iacute",          0x00ed, -1 },
+  { US"ibreve",          0x012d, -1 },
   { US"icircumflex",     0x00ee, -1 },
   { US"idieresis",       0x00ef, -1 },
   { US"igrave",          0x00ec, -1 },
+  { US"ij",              0x0133, -1 },
   { US"imacron",         0x012b, -1 },
+  { US"infinity",        0x221e, 43 },
   { US"iogonek",         0x012f, -1 },
+  { US"itilde",          0x0129, -1 },
   { US"j",               0x006a, -1 },
+  { US"jcircumflex",     0x0135, -1 },
   { US"k",               0x006b, -1 },
   { US"kcommaaccent",    0x0137, -1 },
+  { US"kgreenlandic",    0x0138, -1 },
   { US"l",               0x006c, -1 },
   { US"lacute",          0x013a, -1 },
   { US"lcaron",          0x013e, -1 },
   { US"lcommaaccent",    0x013c, -1 },
+  { US"ldot",            0x0140, -1 },
   { US"less",            0x003c, -1 },
   { US"lessequal",       0x2264, 22 },
   { US"logicalnot",      0x00ac, -1 },
+  { US"longs",           0x017f, -1 },
   { US"lozenge",         0x25ca, 23 },
   { US"lslash",          0x0142, -1 },
   { US"m",               0x006d, -1 },
@@ -249,6 +286,7 @@ static an2uencod an2ulist[] = {
   { US"multiply",        0x00d7, -1 },
   { US"n",               0x006e, -1 },
   { US"nacute",          0x0144, -1 },
+  { US"napostrophe",     0x0149, -1 },
   { US"ncaron",          0x0148, -1 },
   { US"ncommaaccent",    0x0146, -1 },
   { US"nine",            0x0039, -1 },
@@ -257,6 +295,7 @@ static an2uencod an2ulist[] = {
   { US"numbersign",      0x0023, -1 },
   { US"o",               0x006f, -1 },
   { US"oacute",          0x00f3, -1 },
+  { US"obreve",          0x014f, -1 },
   { US"ocircumflex",     0x00f4, -1 },
   { US"odieresis",       0x00f6, -1 },
   { US"oe",              0x0153, -1 },
@@ -305,6 +344,7 @@ static an2uencod an2ulist[] = {
   { US"sacute",          0x015b, -1 },
   { US"scaron",          0x0161, -1 },
   { US"scedilla",        0x015f, -1 },
+  { US"scircumflex",     0x015d, -1 },
   { US"scommaaccent",    0x0219, 38 },
   { US"section",         0x00a7, -1 },
   { US"semicolon",       0x003b, -1 },
@@ -315,7 +355,9 @@ static an2uencod an2ulist[] = {
   { US"sterling",        0x00a3, -1 },
   { US"summation",       0x2211, 39 },
   { US"t",               0x0074, -1 },
+  { US"tbar",            0x0167, -1 },
   { US"tcaron",          0x0165, -1 },
+  { US"tcedilla",        0x0163, -1 },
   { US"tcommaaccent",    0x021b, 40 },
   { US"thorn",           0x00fe, -1 },
   { US"three",           0x0033, -1 },
@@ -327,6 +369,7 @@ static an2uencod an2ulist[] = {
   { US"twosuperior",     0x00b2, -1 },
   { US"u",               0x0075, -1 },
   { US"uacute",          0x00fa, -1 },
+  { US"ubreve",          0x016d, -1 },
   { US"ucircumflex",     0x00fb, -1 },
   { US"udieresis",       0x00fc, -1 },
   { US"ugrave",          0x00f9, -1 },
@@ -335,11 +378,14 @@ static an2uencod an2ulist[] = {
   { US"underscore",      0x005f, -1 },
   { US"uogonek",         0x0173, -1 },
   { US"uring",           0x016f, -1 },
+  { US"utilde",          0x0169, -1 },
   { US"v",               0x0076, -1 },
   { US"w",               0x0077, -1 },
+  { US"wcircumflex",     0x0175, -1 },
   { US"x",               0x0078, -1 },
   { US"y",               0x0079, -1 },
   { US"yacute",          0x00fd, -1 },
+  { US"ycircumflex",     0x0177, -1 },
   { US"ydieresis",       0x00ff, -1 },
   { US"yen",             0x00a5, -1 },
   { US"z",               0x007a, -1 },
