@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2012 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: January 2012 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains initializing code, including the main program, which is
@@ -40,7 +40,7 @@ that hark back to the original, event-driven implementation. */
 /* Keywords for the command line. If you increase the number of keys, make sure
 that the keyoffset field in rdargs.c is big enough. */
 
-static char *arg_pattern =
+static const char *arg_pattern =
   ","
   "a4ona3/s,"
   "a4sideways/s,"
@@ -78,7 +78,7 @@ static char *arg_pattern =
   "s/k,"
   "t/k/n,"
   "tumble/s,"
-  "V/s,"
+  "-version=V/s,"
   "v/s";
 
 /* Offsets for command line keys */
@@ -222,7 +222,7 @@ Returns:      nothing
 */
 
 void 
-info_printf(char *format, ...)
+info_printf(const char *format, ...)
 {
 uschar buff[256];
 va_list ap;
