@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2013 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: January 2013 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains code for writing a MIDI file */
@@ -336,7 +336,7 @@ writebar(BOOL is_lastbar)
 BOOL hadrepeat = FALSE;
 BOOL oknbar = TRUE;
 int stave;
-int *p = play_movt->play_tempo_changes;
+int *ptc = play_movt->play_tempo_changes;
 int this_barlength = find_barlength();
 midi_event *eptr, *neptr;
 
@@ -344,13 +344,13 @@ DEBUG(("writebar %d\n", play_bar));
 
 /* Find the tempo for this bar */
 
-if (p != NULL && play_bar >= *p)
+if (ptc != NULL && play_bar >= *ptc)
   {
-  while (play_bar >= *p) p += 2;
-  if (p[-1] != play_tempo)
+  while (play_bar >= *ptc) ptc += 2;
+  if (ptc[-1] != play_tempo)
     {
     int temp;
-    play_tempo = p[-1];
+    play_tempo = ptc[-1];
     temp = 60000000/play_tempo;     /* Microseconds per crotchet */
     next_event->time = 0;
     next_event->seq = next_event_seq++;
@@ -869,7 +869,7 @@ if (start_bar > 1)
     {
     if (change->barno < play_bar)
       {
-      int stave = change->stave;
+      stave = change->stave;
 
       /* If change volume occurs with midi channel change, it is a
       channel volume change, not a stave volume change. */
