@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2010 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: November 2010 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains code for splitting the music bars into systems and making
@@ -131,7 +131,7 @@ while (!page_done) switch(page_state)
   case page_state_newmovt:
   format_movt = curmovt;
 
-  if (curmovt->barlinespace == 0x80000000)
+  if (curmovt->barlinespace == (int)0x80000000)
     {
     page_barlinewidth = (curmovt->notespacing)[minim]/2 - 5000;
     if (page_barlinewidth < 3000) page_barlinewidth = 3000;
@@ -306,7 +306,6 @@ while (!page_done) switch(page_state)
 
   case page_state_newsystem:
     {
-    int i;
     int keyxposition = 0;
     int timexposition = 0;
     int timewidth = 0;
@@ -367,7 +366,8 @@ while (!page_done) switch(page_state)
     /* Initialize those fields of the current data structure that are reset for
     each system */
 
-    page_accepteddata->endkeytime = FALSE;
+    page_accepteddata->endkey = FALSE;
+    page_accepteddata->endtime = FALSE;
     page_accepteddata->endbar = page_barnumber - 1;
     page_accepteddata->count = 0;
     
@@ -410,9 +410,9 @@ while (!page_done) switch(page_state)
         if ((curmovt->stavetable[i])->stavelines < 127)
           {
           int clef = (page_sysblock->cont[i]).clef;
-          int xposition =
+          int xpos =
             curmovt->clefwidths[clef] * main_stavemagn + page_startline->clefspace;
-          if (xposition > keyxposition) keyxposition = xposition;
+          if (xpos > keyxposition) keyxposition = xpos;
           }
         }
       }
@@ -430,9 +430,9 @@ while (!page_done) switch(page_state)
         if ((curmovt->stavetable[i])->stavelines < 127)
           {
           int key = (page_sysblock->cont[i]).key;
-          int xposition = keyxposition +
+          int xpos = keyxposition +
             (main_stavemagn * misc_keywidth(key, page_sysblock->cont[i].clef))/1000;
-          if (xposition > timexposition) timexposition = xposition;
+          if (xpos > timexposition) timexposition = xpos;
           if (key != 2) Cmajor = FALSE;
           }
         }
@@ -517,15 +517,15 @@ while (!page_done) switch(page_state)
 
   *page_nextdata = *page_accepteddata;
 
-  /* Measure the bar -- this also sets various flags such as page_warnkeytime
-  and also sets page_xxwidth if there is a key and/or time signature. The 
-  lengthwarn variable is normally zero (or less), but is set to 1 after the end 
-  of a system so that re-measuring the bar, for the next system, doesn't give a 
-  length warning again. If we back up two bars, in order to fit in a key/time 
+  /* Measure the bar -- this also sets various flags such as page_warnkey and
+  also sets page_xxwidth if there is a key and/or time signature. The
+  lengthwarn variable is normally zero (or less), but is set to 1 after the end
+  of a system so that re-measuring the bar, for the next system, doesn't give a
+  length warning again. If we back up two bars, in order to fit in a key/time
   signature, lengthwarn is set to 2. */
   
   nextbarwidth = page_makepostable(lengthwarn-- < 1);
-
+  
   /* Compute position if bar were accepted */
 
   xposition = page_accepteddata->xposition + nextbarwidth;
@@ -547,7 +547,6 @@ while (!page_done) switch(page_state)
   if (mac_diffstave(page_nextdata->notsuspend, page_accepteddata->notsuspend) ||
       page_nextdata->stavenames != page_accepteddata->stavenames)
     {
-    int i;
     int newkeyxposition = 0;
     int newtimexposition = 0;
 
@@ -613,13 +612,13 @@ while (!page_done) switch(page_state)
 
     /* See if cautionary signature(s) are needed. */
 
-    if (!page_startlinebar && page_warnkeytime)
+    if (!page_startlinebar && (page_warnkey || page_warntime))
       {
       xposition = page_accepteddata->xposition + page_xxwidth;
 
-      /* If there is not even enough space for the end-of-line signature, back
-      up to the previous bar, unless there isn't one to back up to, in which
-      case give an overlong line warning. */
+      /* If there is not even enough space for the end-of-line signature(s),
+      back up to the previous bar, unless there isn't one to back up to, in
+      which case give an overlong line warning. */
 
       if (page_layoutptr < 0 && xposition > curmovt->linelength)
         {
@@ -640,12 +639,13 @@ while (!page_done) switch(page_state)
           }
         }
 
-      /* Room for key/time -- set flag and xposition */
+      /* Room for key/time -- set flag(s) and xposition */
        
       else
         {
         page_accepteddata->xposition = xposition + page_barlinewidth;
-        page_accepteddata->endkeytime = TRUE;
+        page_accepteddata->endkey = page_warnkey;
+        page_accepteddata->endtime = page_warntime;
         }
       }
 
@@ -685,9 +685,14 @@ while (!page_done) switch(page_state)
     if (page_xxwidth > 0 && !page_startlinebar)
       {
       page_previousdata->xposition += page_xxwidth + page_barlinewidth;
-      page_previousdata->endkeytime = TRUE;
+      page_previousdata->endkey = page_warnkey;
+      page_previousdata->endtime = page_warntime;
       }
-    else page_previousdata->endkeytime = FALSE;
+    else 
+      {
+      page_previousdata->endkey = FALSE;
+      page_previousdata->endtime = FALSE;
+      } 
 
     /* Allow for key & time signature positioning adjustment */
 
@@ -738,7 +743,7 @@ while (!page_done) switch(page_state)
     {
     int startxposition = page_accepteddata->startxposition;
     int barlinewidth = page_barlinewidth; 
-    int i, justbits, stretchn, stretchd, sysdepth, sysfootdepth;
+    int justbits, stretchn, stretchd, sysdepth, sysfootdepth;
     
     page_sysblock->stavenames = page_accepteddata->stavenames;
     page_sysblock->barend = page_accepteddata->endbar;
@@ -760,7 +765,8 @@ while (!page_done) switch(page_state)
     page_sysblock->timexposition += startxposition;
     page_sysblock->firstnoteposition += startxposition;
 
-    if (page_accepteddata->endkeytime) page_sysblock->flags |= sysblock_warn;
+    if (page_accepteddata->endkey) page_sysblock->flags |= sysblock_warnkey;
+    if (page_accepteddata->endtime) page_sysblock->flags |= sysblock_warntime;
 
     /* Advance the continuation data to the end of the system, ready for the
     next one. This scan also handles changes of stave and system spacing, and
@@ -805,10 +811,10 @@ while (!page_done) switch(page_state)
             main_stretchthreshden) ||
               xposition > curmovt->linelength)
       {
-      int i = 0; 
       int save_xxwidth = page_xxwidth; 
       int xxadjust = page_sysblock->firstnoteposition +
-        (page_accepteddata->endkeytime? page_xxwidth + barlinewidth : 0);
+        ((page_accepteddata->endkey || page_accepteddata->endtime)? 
+          page_xxwidth + barlinewidth : 0);
 
       stretchn = curmovt->linelength - xxadjust;
       stretchd = xposition - xxadjust;
@@ -837,6 +843,7 @@ while (!page_done) switch(page_state)
       page_layout_stretchn = stretchn;
       page_layout_stretchd = stretchn;   /* sic - see below - it changes cumulatively */
 
+      i = 0; 
       while (i++ < 4 &&
              (
              (mac_muldiv(stretchd, 1000, stretchn) > main_stretchrespacethresh && 
@@ -872,7 +879,7 @@ while (!page_done) switch(page_state)
           }
 
         xposition -= barlinewidth;
-        if (page_accepteddata->endkeytime) 
+        if (page_accepteddata->endkey || page_accepteddata->endtime) 
           xposition += save_xxwidth + curmovt->barlinespace;  /* Unstretched barlinewidth */
         stretchd = xposition - xxadjust;
 
@@ -1019,7 +1026,6 @@ while (!page_done) switch(page_state)
       if (curmovt->startbracketbar >= page_sysblock->barstart &&
           curmovt->startbracketbar <  page_sysblock->barend)
         {
-        int i;
         int blw = 0;
         page_sysblock->joinxposition = page_sysblock->firstnoteposition;
         for (i = page_sysblock->barstart; i <= curmovt->startbracketbar; i++)
