@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2012 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: March 2012 */
+/* This file last modified: June 2016 */
 
 /* This is the main header file, imported by all other sources. */
 
@@ -163,7 +163,7 @@ addresses. They used to be punned, stuffing pointers into ints, but this
 doesn't work in 64-bit environments. */
 
 typedef struct {
-  int dtype;                      /* data type, eg dd_number */
+  unsigned int dtype;             /* data type, eg dd_number */
   union {
     void *ptr;
     int   val;
@@ -725,7 +725,8 @@ typedef struct {
   int   notespacing[8];        /* notespacing values */
   unsigned int notsuspend[stave_bitvec_size];  /* not suspended staves */
   snamestr **stavenames;       /* stave name vector */
-  CBOOL endkeytime;            /* line ends with key or time signature */
+  CBOOL endkey;                /* line ends with key signature */
+  CBOOL endtime;               /* line ends with time signature */
 } pagedatastr;
 
 
@@ -865,6 +866,7 @@ typedef struct {
   CBOOL breverests;
   CBOOL check;
   CBOOL checkdoublebars;
+  CBOOL codemultirests; 
   CBOOL fullbarend;
   CBOOL startjoin;
   CBOOL keydoublebar;
@@ -1030,9 +1032,11 @@ typedef struct sysblock {
 
 /* Flag bits */
 
-#define sysblock_warn      1    /* print additional warning bar */
-#define sysblock_stretch   2    /* flag set when stretched */
-#define sysblock_noadvance 4    /* don't advance vertically */
+#define sysblock_warnkey   1    /* print additional key signature warning bar */
+#define sysblock_warntime  2    /* ditto, time signature */
+#define sysblock_warn      3    /* mask for either one of the above */
+#define sysblock_stretch   4    /* flag set when stretched */
+#define sysblock_noadvance 8    /* don't advance vertically */
 
 
 /* Layout of data in a head block structure. Up to and including the movement
@@ -1071,7 +1075,7 @@ typedef struct mfstr {
   struct mfstr *next;
   int x;
   int y;
-  int ch;  /* Holds up to 4 chars */
+  unsigned int ch;  /* Holds up to 4 chars */
 } mfstr;
 
 
@@ -1163,8 +1167,10 @@ extern zcopystr init_zcopy;            /* Default stave zero copy structure */
 extern FILE *input_file;               /* The current input file */
 
 extern uschar length_table[];          /* Table of item lengths */
+extern int  longrest_barwidths[];      /* Fixed widths for longrest bars */
+extern int  longrest_widths[];         /* Widths of longrest symbols */
 
-extern int  main_bit[];                /* Table of bits in a word */
+extern unsigned int main_bit[];        /* Table of bits in a word */
 extern uschar *main_caesurastrings[];  /* For printing caesuras */
 extern int  main_clefoffset[];         /* Offsets in tables for clefs */
 extern int  main_cleftypes[];          /* Types of shape indicators for next */
@@ -1283,7 +1289,7 @@ extern uschar version_string[];        /* Identity of program version */
 *                 Global procedures              *
 *************************************************/
 
-extern void debug_printf(char *, ...);
+extern void debug_printf(const char *, ...);
 extern void debug_showbar(int, int, int);
 
 #ifdef Debug
@@ -1306,15 +1312,15 @@ extern void  font_rotate(int);
 extern int   font_search(uschar *);
 extern int   font_stringwidth(uschar *, int, int);
 
-extern int   format_sprintf(uschar *, char *, ...);      /* 2nd is format */
-extern int   format_vsprintf(uschar *, char *, va_list); /* ditto */
+extern int   format_sprintf(uschar *, const char *, ...);      /* 2nd is format */
+extern int   format_vsprintf(uschar *, const char *, va_list); /* ditto */
 
-extern void  info_printf(char *, ...);
-extern int   init_command(int, char **, char ***, char *);
+extern void  info_printf(const char *, ...);
+extern int   init_command(int, char **, char ***, const char *);
 
 extern void  main_tidyup(void);
 
-extern void  midi_write();
+extern void  midi_write(void);
 
 extern void       misc_commoncont(bstr *);
 extern contstr   *misc_copycontstr(contstr *, int, BOOL);
@@ -1342,7 +1348,7 @@ extern uschar *store_copystring(uschar *);
 extern void  store_debug_print(void);
 extern void  store_debug_print(void);
 extern void  store_free(void *);
-extern void *store_get(int);
+extern void *store_get(unsigned int);
 extern void *store_getitem(int);
 extern void *store_nextitem(void);
 extern void *store_Xget(int);
