@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2013 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: March 2013 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains the main code for creating a position table for a bar. It
@@ -586,8 +586,8 @@ rigmarole. The length of such bars is fixed. */
 
 if (page_manyrest >= 2)
   {
-  int i = (curmovt->codemultirests && page_manyrest < 9)? page_manyrest : 0;
-  page_posptr->xoff = longrest_barwidths[i]*main_stavemagn;
+  int ii = (curmovt->codemultirests && page_manyrest < 9)? page_manyrest : 0;
+  page_posptr->xoff = longrest_barwidths[ii]*main_stavemagn;
   pos_bp->multi = page_manyrest;
   }
 
@@ -1294,7 +1294,7 @@ if (curmovt->spreadunderlay)
               (t->ulen != 1 || t->string[0] != '='))
             {
             int w = 0;
-            int left, right, j;
+            int leftx, rightx, j;
             int fontsize = mac_muldiv(main_stavemagn,
               ((curmovt->fontsizes)->fontsize_text)[t->size], 1000);
             int *matrix = ((curmovt->fontsizes)->fontmatrix_text)[t->size];
@@ -1305,7 +1305,7 @@ if (curmovt->spreadunderlay)
             uschar *qq = ss;
             uschar *cc = ss;
 
-            left = t->x;
+            leftx = t->x;
 
             if (matrix != NULL) memcpy(font_transform, matrix, 4*sizeof(int));
 
@@ -1337,7 +1337,7 @@ if (curmovt->spreadunderlay)
               for (k = i+1; k < t->ulen; k++) if ((t->string)[k] == '^') break;
               if (k >= t->ulen) break;
 
-              left -= string_width(ss, t->font, fontsize);
+              leftx -= string_width(ss, t->font, fontsize);
               cc = qq;
               pp++;
               i++;
@@ -1350,7 +1350,7 @@ if (curmovt->spreadunderlay)
                  (*pp != '=' && (*pp != '-' || pp[1] != '=')))
               {
               w = string_width(cc, t->font, fontsize);
-              if (w != 0) left += 3*main_stavemagn - w/2;
+              if (w != 0) leftx += 3*main_stavemagn - w/2;
 
               if (*pp == '^')
                 {
@@ -1391,7 +1391,7 @@ if (curmovt->spreadunderlay)
 
             /* Fontsize/4 is the space to the next syllable */
 
-            right = left + fontsize/4 +
+            rightx = leftx + fontsize/4 +
               (same? w : string_width(ss, t->font, fontsize));
 
             /* Correct for leading spaces, but not if they were originally
@@ -1403,21 +1403,21 @@ if (curmovt->spreadunderlay)
               qq = ss;
               while (*pp++ != '#' && *qq++ == ' ');  /* Test order matters */
               *qq = 0;
-              left += font_stringwidth(ss, t->font, fontsize);
+              leftx += font_stringwidth(ss, t->font, fontsize);
               }
 
             /* Keep maximum for verses, separately for under- and overlay */
 
             if ((flags & text_above) != 0)
               {
-              if (nextleftO > left) nextleftO = left;
-              if (nextrightO < right) nextrightO = right;
+              if (nextleftO > leftx) nextleftO = leftx;
+              if (nextrightO < rightx) nextrightO = rightx;
               hadolay = TRUE;
               }
             else
               {
-              if (nextleftU > left) nextleftU = left;
-              if (nextrightU < right) nextrightU = right;
+              if (nextleftU > leftx) nextleftU = leftx;
+              if (nextrightU < rightx) nextrightU = rightx;
               hadulay = TRUE;
               }
 
