@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2012 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: January 2012 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains code for outputting things in PostScript */
@@ -65,7 +65,7 @@ Returns:      nothing
 */
 
 static 
-void ps_printf(char *format, ...)
+void ps_printf(const char *format, ...)
 {
 int len;
 uschar buff[256];
@@ -872,9 +872,9 @@ ps_chcount = 0;
 *           Output one musical character         *
 *************************************************/
 
-/* Certain musical characters are given identity numbers that may or may not
-correspond directly to characters in the music font. The table called
-out_mftable[] defines how they are to be printed.
+/* Certain musical characters are given identity numbers in a virtual music
+font that may or may not correspond directly to characters in the actual music
+font. The table called out_mftable_ps[] defines how they are to be printed.
 
 Arguments:
   x          the x coordinate
@@ -888,23 +888,15 @@ Returns:     nothing
 void 
 ps_muschar(int x, int y, int ch, int pointsize)
 {
-int xfudge = 0;
-mfstr *p = out_mftable_ps[ch];
 uschar s[10];
+mfstr *p;
+int xfudge = 0;
 
-/* One-to-one mappings are represented by small integers */
+/* There may be a chain of strings/displacements */
 
-if ((long int)p < 256)
+for (p = out_mftable_ps[ch]; p != NULL; p = p->next)
   {
-  s[misc_ord2utf8((long int)p, s)] = 0;
-  ps_basic_string(s, font_mf, pointsize, TRUE, x, y, 0);
-  }
-
-/* Otherwise there may be a chain of strings/displacements */
-
-else do
-  {
-  int c = p->ch;
+  unsigned int c = p->ch;
   int i = 0;
   int nxfudge = 0;  
   
@@ -934,10 +926,8 @@ else do
     x + mac_muldiv(p->x, pointsize, 10000) + xfudge,
     y - mac_muldiv(p->y, pointsize, 10000), 0);
 
-  p = p->next;
   xfudge += nxfudge; 
   }
-while (p != NULL);
 }
 
 
@@ -1096,7 +1086,8 @@ ps_line(int x0, int y0, int x1, int y1, int thickness, int flags)
 uschar *reset = US"";
 double xx = (double)((int)(x1 - x0));
 double yy = (double)((int)(y1 - y0));
-int len =  (int)(sqrt(xx*xx + yy*yy));
+double zz = sqrt(xx*xx + yy*yy);
+int len = (int)zz;  /* Don't cast sqrt; it gives a compiler warning */
 int dashlength = 0;
 int gaplength = 0;
 int dashcount, spacecount;
@@ -1561,7 +1552,7 @@ Returns:   nothing
 */
 
 static void 
-include_font(char *name)
+include_font(const char *name)
 {
 FILE *f = NULL;
 uschar buff[256];
