@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 2nd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2010 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: December 2010 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains part I of the code for reading in a PMW score file. */
@@ -112,8 +112,8 @@ while (inptr < inend)
             /* Optimize the case with no arguments */
 
             if (mm->argcount == 0)
-              { 
-              if (outlen - 2 - (temp - next_buffer) < k + (inend - inptr))
+              {
+              if (outlen - 2 - (temp - outbuffer) < k + (inend - inptr))
                 error_moan(88);   /* hard error - buffer overflow */
               Ustrcpy(temp, mm->text);
               temp += k;
@@ -124,7 +124,6 @@ while (inptr < inend)
                
             else
               {
-              int i; 
               int argcount = mm->argcount;
               uschar *pp = mm->text;
               uschar *args[20]; 
@@ -144,29 +143,29 @@ while (inptr < inend)
                   {
                   int bracount = 0; 
                   BOOL inquotes = FALSE; 
-                  uschar *s = ap; 
+                  uschar *ss = ap; 
                   while (++inptr < inend && 
                         ((*inptr != ',' && *inptr != ')') ||
                           bracount > 0 || inquotes))  
                     {
-                    int ch = *inptr; 
-                    if (ch == '&' && !isalnum(inptr[1])) 
+                    int cch = *inptr; 
+                    if (cch == '&' && !isalnum(inptr[1])) 
                       *ap++ = *(++inptr); 
                     else
                       { 
-                      if (ch == '\"') inquotes = !inquotes; 
+                      if (cch == '\"') inquotes = !inquotes; 
                       if (!inquotes)
                         { 
-                        if (ch == '(') bracount++;
-                          else if (ch == ')') bracount--; 
+                        if (cch == '(') bracount++;
+                          else if (cch == ')') bracount--; 
                         }   
-                      *ap++ = ch;
+                      *ap++ = cch;
                       } 
                     }
                     
                   if (inptr >= inend) error_moan(99);
                   if (i >= argcount) { args[i] = NULL; argcount++; }
-                  if (ap - s > 0) { *ap++ = 0; args[i] = s; }  
+                  if (ap - ss > 0) { *ap++ = 0; args[i] = ss; }  
                     
                   if (inptr >= inend || *inptr == ')')
                     { inptr++; break; } 
@@ -196,19 +195,19 @@ while (inptr < inend)
                   if (*pp == ';') pp++;
                   if (--arg < argcount)
                     {
-                    uschar *s = args[arg];
-                    if (s != NULL)
+                    uschar *ss = args[arg];
+                    if (ss != NULL)
                       {
-                      if (read_buffersize - 2 - (temp - next_buffer) <
-                        Ustrlen(s)) error_moan(88);  /* hard */  
-                      Ustrcpy(temp, s);
-                      temp += Ustrlen(s);    
+                      if (read_buffersize - 2 - (temp - outbuffer) <
+                        Ustrlen(ss)) error_moan(88);  /* hard */  
+                      Ustrcpy(temp, ss);
+                      temp += Ustrlen(ss);    
                       }   
                     }     
                   }
                 else
                   {
-                  if (temp - next_buffer + 2 >= outlen) 
+                  if (temp - outbuffer + 2 >= outlen) 
                     error_moan(88);    /* hard error - buffer overflow */
                   *temp++ = *pp++;    
                   }       
@@ -825,7 +824,6 @@ if (curmovt->play_tempo_changes != NULL)
   while (*p < BIGNUMBER)
     {
     uschar *bv = curmovt->barnovector;
-    int i;
     int n = (*p)/1000 - curmovt->baroffset;
     int f = (*p)%1000;
 
