@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2013 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: March 2013 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains part II of the code for reading in a PMW score file. It
@@ -40,12 +40,12 @@ is in the C language.) */
 static int *global_vars[] = {
   (int *)(&main_magnification),
   (int *)(&main_maxvertjustify),
-  (int *)(&midi_for_notes_off), 
+  (int *)(&midi_for_notes_off),
   (int *)(&opt_oldbeambreak),
   (int *)(&opt_oldrestlevel),
   (int *)(&opt_oldstemlength),
   (int *)(&main_truepagelength),
-  (int *)(&main_righttoleft), 
+  (int *)(&main_righttoleft),
   (int *)(&main_sheetheight),
   (int *)(&main_sheetwidth),
   (int *)(&opt_stretchrule),
@@ -55,12 +55,12 @@ static int *global_vars[] = {
 enum {
   glob_magnification,
   glob_maxvertjustify,
-  glob_midifornotesoff, 
+  glob_midifornotesoff,
   glob_oldbeambreak,
   glob_oldrestlevel,
   glob_oldstemlength,
   glob_pagelength,
-  glob_righttoleft, 
+  glob_righttoleft,
   glob_sheetdepth,
   glob_sheetwidth,
   glob_stretchrule,
@@ -88,7 +88,7 @@ Argument:   the offset for the result
 Returns:    nothing
 */
 
-static void 
+static void
 set_fontname(int offset)
 {
 sigch();
@@ -115,22 +115,25 @@ if (isalpha(read_ch))
 *           Read and set font size               *
 *************************************************/
 
-/* This is for the table of font sizes in the movement structure. If the next 
+/* This is for the table of font sizes in the movement structure. If the next
 thing in the input is a digit, read it as a font size. If not, do nothing.
+The size may be followed by a stretch and shear, if permitted.
 
 Arguments:
-  offset      offset in current movement data structure for the result
+  offset      offset in current movement data structure for the size result
   stretchOK   TRUE if stretch and/or shearing are permitted for the font
-  
-Returns:      nothing  
+
+Returns:      nothing
 */
 
-static void 
+static void
 set_fontsize(int offset, BOOL stretchOK)
 {
 sigch();
 if (isdigit(read_ch))
   {
+  int *sizeptr, **matrixptr;
+
   if (!read_copied_fontsizestr)
     {
     fontsizestr *new = store_Xget(sizeof(fontsizestr));
@@ -138,9 +141,22 @@ if (isdigit(read_ch))
     curmovt->fontsizes = new;
     read_copied_fontsizestr = TRUE;
     }
-  *((int *)(((uschar *)(curmovt->fontsizes)) + offset)) = read_integer(TRUE);
-  *((int **)(((uschar *)(curmovt->fontsizes)) + offset +
-        oo(fontsizestr, fontmatrix_music))) = NULL;
+
+  /* Compute the addresses of where to put the size and the stretch/shear
+  matrix, allowing for the fact that pointers may not be the same size as ints,
+  an error that wasn't fixed till February 2014. */
+
+  sizeptr = (int *)(((uschar *)(curmovt->fontsizes)) + offset);
+  matrixptr = (int **)((uschar *)(curmovt->fontsizes) +
+              oo(fontsizestr, fontmatrix_music) +
+              (offset/sizeof(int)) * sizeof(int *));
+
+  /* Read size, default no matrix */
+
+  *sizeptr = read_integer(TRUE);
+  *matrixptr = NULL;
+  
+  /* Handle stretch and shear */ 
 
   if (read_ch == '/')
     {
@@ -156,8 +172,7 @@ if (isdigit(read_ch))
     if (!stretchOK) error_moan(97, "allowed", "with this directive"); else
       {
       int *matrix = store_Xget(4*sizeof(int));
-      *((int **)(((uschar *)(curmovt->fontsizes)) + offset +
-        oo(fontsizestr, fontmatrix_music))) = matrix;
+      *matrixptr = matrix;
       matrix[0] = mac_muldiv(stretch, 65536, 1000);
       matrix[1] = 0;
       matrix[2] = (int)(tan(((double)shear)*atan(1.0)/45000.0)*65536.0);
@@ -182,7 +197,7 @@ if (isdigit(read_ch))
 *           Deal with plain font size            *
 *************************************************/
 
-static void 
+static void
 movt_fszproc(void)
 {
 sigch();
@@ -195,7 +210,7 @@ if (isdigit(read_ch)) set_fontsize(read_dir->arg1, read_dir->arg2);
 *           Deal with heading boolean            *
 *************************************************/
 
-static void 
+static void
 movt_cboolproc(void)
 {
 *((CBOOL *)((uschar *)curmovt + read_dir->arg1)) = read_dir->arg2;
@@ -206,7 +221,7 @@ movt_cboolproc(void)
 *            Deal with heading font              *
 *************************************************/
 
-static void 
+static void
 movt_fontproc(void)
 {
 int x;
@@ -220,7 +235,7 @@ if ((x = font_fontword(FALSE)) > 0)
 *           Deal with global boolean             *
 *************************************************/
 
-static void 
+static void
 opt_boolproc(void)
 {
 if (main_lastmovement == 1)
@@ -233,7 +248,7 @@ else error_moan(20);
 *           Deal with heading integer            *
 *************************************************/
 
-static void 
+static void
 movt_intproc(void)
 {
 int x;
@@ -254,7 +269,7 @@ if (read_expect_integer(&x, flags >= int_f, arg2 != int_u))
 *           Deal with global integer            *
 *************************************************/
 
-static void 
+static void
 opt_intproc(void)
 {
 int x;
@@ -273,7 +288,7 @@ if (main_lastmovement != 1) error_moan(20);
 *          Deal with heading stave list          *
 *************************************************/
 
-static void 
+static void
 movt_listproc(void)
 {
 stave_list **p = (stave_list **)(((uschar *)curmovt) + read_dir->arg1);
@@ -313,7 +328,7 @@ while (isdigit(read_ch))
 *          Deal with heading stave map           *
 *************************************************/
 
-static void 
+static void
 movt_mapproc(void)
 {
 mac_initstave(read_map, 0);
@@ -340,7 +355,7 @@ while (isdigit(read_ch))
   }
 
 if (read_dir->arg1 != 0)
-  memcpy(((uschar *)curmovt) + read_dir->arg1, read_map, 
+  memcpy(((uschar *)curmovt) + read_dir->arg1, read_map,
     stave_bitvec_size*sizeof(int));
 }
 
@@ -352,7 +367,7 @@ if (read_dir->arg1 != 0)
 /* The bits in the map remember which have been read, for flushing at the start
 of a new movement. */
 
-static void 
+static void
 movt_headproc(void)
 {
 headstr **oldp = (headstr **)(((uschar *)curmovt) + read_dir->arg1);
@@ -386,7 +401,7 @@ read_headfootingtext(new, read_dir->arg2);
 /* This code is also called from read4 for reading the text of footnotes and
 sysnotes, so it has to be globally addressible. */
 
-void 
+void
 read_headfootingtext(headstr *new, int type)
 {
 int defaultsize = 0;
@@ -406,7 +421,7 @@ if (isalpha(read_ch))
   drawitem *drawargs = NULL;
   drawitem args[20];
   uschar word[80];
-   
+
   read_word(word);
   if (Ustrcmp(word, "draw") != 0)
     {
@@ -417,16 +432,16 @@ if (isalpha(read_ch))
   sigch();
   while (isdigit(read_ch) || read_ch == '-' || read_ch == '+' || read_ch == '\"')
     {
-    if (read_ch == '\"') 
+    if (read_ch == '\"')
       {
       args[++argcount].d.ptr = read_draw_text();
-      args[argcount].dtype = dd_text; 
-      } 
-    else 
+      args[argcount].dtype = dd_text;
+      }
+    else
       {
       if (!read_expect_integer(&(args[++argcount].d.val), TRUE, TRUE)) break;
-      args[argcount].dtype = dd_number; 
-      } 
+      args[argcount].dtype = dd_number;
+      }
     sigch();
     }
 
@@ -434,7 +449,7 @@ if (isalpha(read_ch))
     {
     int i;
     drawargs = store_Xget((argcount+1)*sizeof(drawitem));
-    drawargs[0].dtype = dd_number; 
+    drawargs[0].dtype = dd_number;
     drawargs[0].d.val = argcount;
     for (i = 1; i <= argcount; i++) drawargs[i] = args[i];
     }
@@ -521,7 +536,7 @@ else
 
   new->a.text = string_read();
   new->b.spaceabove = 0;
-  if (new->a.text != NULL && new->size != 0) 
+  if (new->a.text != NULL && new->size != 0)
     new->a.text = string_check(new->a.text);
   }
 
@@ -543,7 +558,7 @@ else new->space = defaultsize;
 *            Accadjusts                          *
 *************************************************/
 
-static void 
+static void
 accadjusts(void)
 {
 int i;
@@ -563,7 +578,7 @@ curmovt->accadjusts = x;
 *            Accspacing                          *
 *************************************************/
 
-static void 
+static void
 accspacing(void)
 {
 int i;
@@ -582,7 +597,7 @@ curmovt->accspacing = x;
 *               Barlinespace                     *
 *************************************************/
 
-static void 
+static void
 barlinespace(void)
 {
 sigch();
@@ -601,7 +616,7 @@ else movt_intproc();
 
 /* A sign is mandatory */
 
-static void 
+static void
 barnumberlevel(void)
 {
 sigch();
@@ -614,7 +629,7 @@ if (read_ch != '+' && read_ch != '-') error_moan(10, "\"+\" or \"-\"");
 *            Barnumbers                          *
 *************************************************/
 
-static void 
+static void
 barnumbers(void)
 {
 int wordread = FALSE;
@@ -652,7 +667,7 @@ set_fontname(oo(movtstr, font_barnumber));
 *              Bracestyle                        *
 *************************************************/
 
-static void 
+static void
 bracestyle(void)
 {
 movt_intproc();
@@ -668,7 +683,7 @@ if (curmovt->bracestyle > 1)
 *            Breakbarlines                       *
 *************************************************/
 
-static void 
+static void
 breakbarlines(void)
 {
 sigch();
@@ -686,7 +701,7 @@ curmovt->fullbarend = FALSE;
 *            Breakbarlinesx                      *
 *************************************************/
 
-static void 
+static void
 breakbarlinesx(void)
 {
 breakbarlines();
@@ -698,7 +713,7 @@ curmovt->fullbarend = TRUE;
 *              Caesurastyle                      *
 *************************************************/
 
-static void 
+static void
 caesurastyle(void)
 {
 movt_intproc();
@@ -714,7 +729,7 @@ if (curmovt->caesurastyle > 1)
 *             Clef size (relative)               *
 *************************************************/
 
-static void 
+static void
 clefsize(void)
 {
 sigch();
@@ -731,7 +746,7 @@ else error_moan(10, "Number");
 *            Clef style                         *
 ************************************************/
 
-static void 
+static void
 clefstyle(void)
 {
 movt_intproc();
@@ -745,20 +760,20 @@ if (curmovt->clefstyle > 3) error_moan(10, "Number less than 4");
 
 static int shape[] = { clef_treble, clef_bass, clef_alto, clef_h, clef_none };
 
-static void 
+static void
 clefwidths(void)
 {
 int i;
 sigch();
 for (i = 0; i < 5 && isdigit(read_ch); i++)
   {
-  int width, j; 
+  int width, j;
   (void)read_expect_integer(&width, FALSE, FALSE);
   if (read_ch == ',') next_ch();
   sigch();
   for (j = 0; j < clef_count; j++)
     if (main_cleftypes[j] == shape[i]) curmovt->clefwidths[j] = width;
-  } 
+  }
 }
 
 
@@ -766,7 +781,7 @@ for (i = 0; i < 5 && isdigit(read_ch); i++)
 *                Copyzero                        *
 *************************************************/
 
-static void 
+static void
 copyzero(void)
 {
 zcopystr **pp = &(curmovt->zcopy);
@@ -798,7 +813,7 @@ while (isdigit(read_ch))
 *              Doublenotes                       *
 *************************************************/
 
-static void 
+static void
 doublenotes(void)
 {
 main_notenum *= 2;
@@ -813,7 +828,7 @@ curmovt->time = read_scaletime(curmovt->time);
 /* Read up to two fixed point numbers, second defaulting to the first; "+" and
 "-" can be used to adjust values. */
 
-static void 
+static void
 gracespacing(void)
 {
 int arg;
@@ -821,24 +836,24 @@ int value = 0;
 BOOL wasrelative = FALSE;
 
 sigch();
-if (read_ch == '+' || read_ch == '-') 
+if (read_ch == '+' || read_ch == '-')
   {
   value = curmovt->gracespacing[0];
-  wasrelative = TRUE; 
-  } 
+  wasrelative = TRUE;
+  }
 if (!read_expect_integer(&arg, TRUE, TRUE)) return;
 curmovt->gracespacing[0] = value + arg;
-    
+
 sigch();
 if (read_ch == ',') next_ch();
 sigch();
-if (!isdigit(read_ch) && read_ch != '+' && read_ch != '-') 
+if (!isdigit(read_ch) && read_ch != '+' && read_ch != '-')
   {
   curmovt->gracespacing[1] = wasrelative?
-    curmovt->gracespacing[1] + arg : 
+    curmovt->gracespacing[1] + arg :
     curmovt->gracespacing[0];
   return;
-  } 
+  }
 
 value = (read_ch == '+' || read_ch == '-')? curmovt->gracespacing[1] : 0;
 if (!read_expect_integer(&arg, TRUE, TRUE)) return;
@@ -850,7 +865,7 @@ curmovt->gracespacing[1] = value + arg;
 *               Halvenotes                       *
 *************************************************/
 
-static void 
+static void
 halvenotes(void)
 {
 if (main_notenum > 1) main_notenum /= 2; else main_noteden *= 2;
@@ -862,7 +877,7 @@ curmovt->time = read_scaletime(curmovt->time);
 *            Hyphenstring                        *
 *************************************************/
 
-static void 
+static void
 hyphenstring(void)
 {
 uschar s[256];
@@ -876,7 +891,7 @@ else error_moan(10, "String");
 *              Justify                           *
 *************************************************/
 
-static void 
+static void
 justify(void)
 {
 int yield = 0;
@@ -910,7 +925,7 @@ curmovt->justify = yield;
 fudged, in case there are transposed text strings in the subsequent header
 lines. The transpose value will already be fudged. */
 
-static void 
+static void
 key(void)
 {
 curmovt->key = read_key();
@@ -923,7 +938,7 @@ stave_key_tp = transpose_key(stave_key, stave_transpose, TRUE);
 *                 Landscape                      *
 *************************************************/
 
-static void 
+static void
 landscape(void)
 {
 int temp = curmovt->truelinelength;
@@ -943,7 +958,7 @@ if (main_lastmovement != 1) error_moan(20);
 *                Layout                          *
 *************************************************/
 
-static void 
+static void
 layout(void)
 {
 int *temp = store_Xget(layout_maxsize * 2 * sizeof(int));
@@ -1055,7 +1070,7 @@ curmovt->ledger = (curmovt->ledger == 0)? '=' : 184;
 *             Maxbeamslope                       *
 *************************************************/
 
-static void 
+static void
 maxbeamslope(void)
 {
 if (!read_expect_integer(&curmovt->maxbeamslope1, TRUE, FALSE)) return;
@@ -1070,7 +1085,7 @@ if (!read_expect_integer(&curmovt->maxbeamslope2, TRUE, FALSE)) return;
 /* Local subroutine to make a copy of a map if this is the first time it's been
 updated in this movement. */
 
-static void 
+static void
 copy_midi_map(int flag, int size, uschar **anchor)
 {
 if ((read_headmap & flag) == 0)
@@ -1084,7 +1099,7 @@ if ((read_headmap & flag) == 0)
 
 /* The main function */
 
-static void 
+static void
 midichannel(void)
 {
 int channel;
@@ -1101,7 +1116,7 @@ if (channel < 1 || channel > midi_maxchannel)
   error_moan(109, "channel", midi_maxchannel);
   channel = 1;
   }
-  
+
 /* Deal with an optional voice setting */
 
 if (read_plainstring(string))
@@ -1171,8 +1186,8 @@ if (isdigit(read_ch))
       }
     }
   }
-   
-debug_printf("midichannel end\n"); 
+
+debug_printf("midichannel end\n");
 }
 
 
@@ -1180,7 +1195,7 @@ debug_printf("midichannel end\n");
 *               Midistart                        *
 *************************************************/
 
-static void 
+static void
 midistart(void)
 {
 int max = 0;
@@ -1200,23 +1215,23 @@ for (;;)
     }
 
   /* Get more store if needed */
-  
-  if (++count > max) 
+
+  if (++count > max)
     {
     int newmax = max + 20;
     int *new = store_Xget((newmax + 1) * sizeof(int));
-    if (max > 0) 
+    if (max > 0)
       {
       memcpy(new, temp, (max+1) * sizeof(int));
       store_free(temp);
-      } 
+      }
     temp = new;
-    max = newmax;   
-    }  
+    max = newmax;
+    }
 
   read_expect_integer(&value, FALSE, FALSE);
   temp[count] = value;
-  } 
+  }
 }
 
 
@@ -1224,7 +1239,7 @@ for (;;)
 *               Notespacing                      *
 *************************************************/
 
-static void 
+static void
 notespacing(void)
 {
 int i;
@@ -1262,7 +1277,7 @@ else
 *            Oldstretchrule                      *
 *************************************************/
 
-/* This used to be a standard boolean, but it's now extended to an integer 
+/* This used to be a standard boolean, but it's now extended to an integer
 option called "stretchrule". This is a backwards-compatibility function. */
 
 static void
@@ -1276,7 +1291,7 @@ opt_stretchrule = 0;
 *               Page                             *
 *************************************************/
 
-static void 
+static void
 page(void)
 {
 main_pageinc = 1;
@@ -1293,7 +1308,7 @@ read_expect_integer(&main_pageinc, FALSE, FALSE);
 *               Playtempo                        *
 *************************************************/
 
-static void 
+static void
 playtempo(void)
 {
 movt_intproc();           /* Read a single number */
@@ -1355,7 +1370,7 @@ if (isdigit(read_ch))
 *              Playtranspose                     *
 *************************************************/
 
-static void 
+static void
 playtranspose(void)
 {
 sigch();
@@ -1385,8 +1400,8 @@ while (isdigit(read_ch))
 *               Playvolume                       *
 *************************************************/
 
-static void 
-playvolume()
+static void
+playvolume(void)
 {
 int i, v;
 uschar *vv;
@@ -1435,7 +1450,7 @@ while (isdigit(read_ch))
 *             PMW version check                  *
 *************************************************/
 
-static void 
+static void
 pmwversion(void)
 {
 int v;
@@ -1454,11 +1469,11 @@ number.
 Arguments:
   s          pointer to where to put a pointer to the string
   offset     pointer to where to put the font offset
-  
-Returns:     TRUE if all goes well; FALSE on error  
+
+Returns:     TRUE if all goes well; FALSE on error
 */
 
-static BOOL 
+static BOOL
 ptstring(uschar **s, uschar *offset)
 {
 *s = string_check(string_read());
@@ -1488,7 +1503,7 @@ return TRUE;
 
 /* The actual routine */
 
-static void 
+static void
 printtime(void)
 {
 ptimestr *p = store_Xget(sizeof(ptimestr));
@@ -1522,7 +1537,7 @@ p->string = string_check(string_read());
 *                 Pssetup                        *
 *************************************************/
 
-static void 
+static void
 pssetup(void)
 {
 if (main_lastmovement != 1) error_moan(20); else
@@ -1556,7 +1571,7 @@ if (main_lastmovement != 1) error_moan(20); else
 *              Rehearsalmarks                    *
 *************************************************/
 
-static void 
+static void
 rehearsalmarks(void)
 {
 uschar word[80];
@@ -1579,7 +1594,7 @@ set_fontname(oo(movtstr, font_rehearse));
 *        Sheetdepth and sheetwidth               *
 *************************************************/
 
-static void 
+static void
 sheetdim(void)
 {
 opt_sheetsize = sheet_unknown;
@@ -1591,7 +1606,7 @@ opt_intproc();
 *                 Sheetsize                      *
 *************************************************/
 
-static void 
+static void
 sheetsize(void)
 {
 uschar word[80];
@@ -1645,7 +1660,7 @@ if (main_lastmovement != 1) error_moan(20);
 *               Startbracketbar                  *
 *************************************************/
 
-static void 
+static void
 startbracketbar(void)
 {
 sigch();
@@ -1666,7 +1681,7 @@ read_expect_integer(&curmovt->startbracketbar, FALSE, FALSE);
 *               Stavesize                        *
 *************************************************/
 
-static void 
+static void
 stavesize(void)
 {
 int *stavesizes = store_Xget((max_stave+1)*sizeof(int));
@@ -1693,7 +1708,7 @@ while (isdigit(read_ch))
 *                Stavespacing                    *
 *************************************************/
 
-static void 
+static void
 stavespacing(void)
 {
 BOOL first = TRUE;
@@ -1724,7 +1739,7 @@ while (isdigit(read_ch))
     {
     if (first)
       {
-      int space = stave*1000;
+      space = stave*1000;
       if (read_ch == '.') space += read_integer(TRUE);
       for (i = 1; i <= max_stave; i++) newsp[i] = space;
       goto NEXT;
@@ -1745,14 +1760,14 @@ while (isdigit(read_ch))
     next_ch();
     if (!read_expect_integer(&space, TRUE, FALSE)) return;
     }
-    
+
   if (stave == 0) error_moan(107); else
-    { 
+    {
     if (mac_teststave(done, stave)) error_moan(106, stave, US"stavespacing");
-    mac_setstave(done, stave); 
+    mac_setstave(done, stave);
     newsp[stave] = space;
     newen[stave] = ensure;
-    } 
+    }
 
 NEXT:
 
@@ -1770,7 +1785,7 @@ curmovt->stave_ensure = newen;
 *               Startlinespacing                 *
 *************************************************/
 
-static void 
+static void
 startlinespacing(void)
 {
 startlinestr *p = store_Xget(sizeof(startlinestr));
@@ -1808,7 +1823,7 @@ curmovt->startline = p;
 *                Stemswap                        *
 *************************************************/
 
-static void 
+static void
 stemswap(void)
 {
 uschar word[100];
@@ -1825,7 +1840,7 @@ else error_moan(10, "\"up\", \"down\", \"left\", or \"right\"");
 *              Stemswaplevel                     *
 *************************************************/
 
-static void 
+static void
 stemswaplevel(void)
 {
 int i, x;
@@ -1860,7 +1875,7 @@ curmovt->stemswaplevel = new;
 *            Stem lengths                       *
 ************************************************/
 
-static void 
+static void
 stemlengths(void)
 {
 int i;
@@ -1870,7 +1885,7 @@ for (i = 2; i < 8 && isdigit(read_ch); i++)
   (void)read_expect_integer(&(curmovt->tailadjusts[i]), TRUE, TRUE);
   if (read_ch == ',') next_ch();
   sigch();
-  } 
+  }
 }
 
 
@@ -1880,7 +1895,7 @@ for (i = 2; i < 8 && isdigit(read_ch); i++)
 
 /* This also handles musicfont, if arg1 is non-zero. */
 
-static void 
+static void
 textfont(void)
 {
 int fontid, n;
@@ -1914,12 +1929,12 @@ if (n >= 0) font_table[fontid] = n; else
   if (font_count >= max_fonts) { error_moan(26, max_fonts); return; }
   fs = &(font_List[font_count]);
   fs->psname = store_copystring(s);
-  fs->widths = NULL; 
-  fs->high_tree = NULL; 
-  fs->heights = NULL; 
+  fs->widths = NULL;
+  fs->high_tree = NULL;
+  fs->heights = NULL;
   fs->kerns = NULL;
-  fs->kerncount = -1; 
-  fs->stdencoding = fs->fixedpitch = fs->hasfi = FALSE; 
+  fs->kerncount = -1;
+  fs->stdencoding = fs->fixedpitch = fs->hasfi = FALSE;
   font_table[fontid] = font_count;
   font_loadtables(font_count++);
   }
@@ -1934,7 +1949,7 @@ if (fontid == font_mf) font_table[font_mu] = font_table[font_mf];
 *            Textsizes                           *
 *************************************************/
 
-static void 
+static void
 textsizes(void)
 {
 int i;
@@ -1950,7 +1965,7 @@ for (i = 0; i < MaxTextFont; i++)
 *                     Time                       *
 *************************************************/
 
-static void 
+static void
 timeproc(void)
 {
 int t = read_time();            /* returns 0 after giving error */
@@ -1963,13 +1978,13 @@ if (t != 0) curmovt->time = t;
 *                Transpose                       *
 *************************************************/
 
-static void 
+static void
 transpose(void)
 {
 int temp = curmovt->transpose;
 movt_intproc();
 if (temp < max_transpose) curmovt->transpose += temp;
-  
+
 /* In case this is followed by heading/footing lines that contain transposed
 text, fudge up some fake stave values. The stave_key will already be set. */
 
@@ -1982,7 +1997,7 @@ stave_key_tp = transpose_key(stave_key, stave_transpose, TRUE);
 *               Transposed key                   *
 *************************************************/
 
-static void 
+static void
 transposedkey(void)
 {
 int oldkey = read_key();
@@ -2006,7 +2021,7 @@ if (Ustrcmp(word, "use") != 0) error_moan(10, "\"use\""); else
 *             Transposed accidental option       *
 *************************************************/
 
-static void 
+static void
 transposedacc(void)
 {
 uschar word[80];
@@ -2021,7 +2036,7 @@ if (Ustrcmp(word, "force") == 0) main_transposedaccforce = TRUE; else
 *             Trill string                       *
 *************************************************/
 
-static void 
+static void
 trillstring(void)
 {
 uschar s[256];
@@ -2051,7 +2066,7 @@ static dirstr read_headlist[] = {
   { "barnumberlevel",   barnumberlevel, oo(movtstr,barno_level), int_rs+int_f },
   { "barnumbers",       barnumbers,     0, 0 },
   { "beamendrests",     movt_cboolproc, oo(movtstr,beamendrests), TRUE },
-  { "beamflaglength",   movt_intproc,   oo(movtstr,beamflaglength), int_u+int_f },  
+  { "beamflaglength",   movt_intproc,   oo(movtstr,beamflaglength), int_u+int_f },
   { "beamthickness",    movt_intproc,   oo(movtstr,beamdepth), int_u+int_f },
   { "bottommargin",     movt_intproc,   oo(movtstr,botmargin), int_u+int_f },
   { "brace",            movt_listproc,  oo(movtstr,bracelist), 0 },
@@ -2067,7 +2082,7 @@ static dirstr read_headlist[] = {
   { "clefsize",         clefsize,       0, 0 },
   { "clefstyle",        clefstyle,      oo(movtstr,clefstyle), int_u },
   { "clefwidths",       clefwidths,     0, 0 },
-  { "codemultirests",   movt_cboolproc, oo(movtstr,codemultirests), TRUE }, 
+  { "codemultirests",   movt_cboolproc, oo(movtstr,codemultirests), TRUE },
   { "copyzero",         copyzero,       0, 0 },
   { "cuegracesize",     movt_fszproc,   oo(fontsizestr,fontsize_cuegrace), FALSE },
   { "cuesize",          movt_fszproc,   oo(fontsizestr,fontsize_cue), FALSE },
@@ -2084,7 +2099,7 @@ static dirstr read_headlist[] = {
   { "footnotesep",      movt_intproc,   oo(movtstr,footnotesep), int_f },
   { "footnotesize",     movt_fszproc,   oo(fontsizestr,fontsize_footnote), TRUE },
   { "gracesize",        movt_fszproc,   oo(fontsizestr,fontsize_grace), FALSE },
-  { "gracespacing",     gracespacing,   0, 0 }, 
+  { "gracespacing",     gracespacing,   0, 0 },
   { "gracestyle",       movt_intproc,   oo(movtstr,gracestyle), int_u },
   { "hairpinlinewidth", movt_intproc,   oo(movtstr,hairpinlinewidth), int_rs+int_f },
   { "hairpinwidth",     movt_intproc,   oo(movtstr,hairpinwidth), int_rs+int_f },
@@ -2113,7 +2128,7 @@ static dirstr read_headlist[] = {
   { "maxvertjustify",   opt_intproc,    glob_maxvertjustify, int_u+int_f },
   { "midichannel",      midichannel,    0, 0 },
   { "midifornotesoff",  opt_boolproc,   glob_midifornotesoff, TRUE },
-  { "midistart",        midistart,      0, 0 }, 
+  { "midistart",        midistart,      0, 0 },
   { "miditempo",        playtempo,      oo(movtstr,play_tempo), int_u },
   { "miditranspose",    playtranspose,  0, 0 },
   { "midivolume",       playvolume,     0, 0 },
@@ -2123,7 +2138,7 @@ static dirstr read_headlist[] = {
   { "nobeamendrests",   movt_cboolproc, oo(movtstr,beamendrests), FALSE },
   { "nocheck",          movt_cboolproc, oo(movtstr,check), FALSE },
   { "nocheckdoublebars",movt_cboolproc, oo(movtstr,checkdoublebars), FALSE },
-  { "nocodemultirests", movt_cboolproc, oo(movtstr,codemultirests), FALSE }, 
+  { "nocodemultirests", movt_cboolproc, oo(movtstr,codemultirests), FALSE },
   { "nokerning",        opt_boolproc,   glob_kerning, FALSE },
   { "nokeywarn",        movt_cboolproc, oo(movtstr,keywarn), FALSE },
   { "nosluroverwarnings", movt_cboolproc, oo(movtstr,tiesoverwarnings), FALSE },
@@ -2132,7 +2147,7 @@ static dirstr read_headlist[] = {
   { "notime",           movt_cboolproc, oo(movtstr,showtime), FALSE },
   { "notimebase",       movt_cboolproc, oo(movtstr,showtimebase), FALSE },
   { "notimewarn",       movt_cboolproc, oo(movtstr,timewarn), FALSE },
-  { "nounderlayextenders",movt_cboolproc, oo(movtstr,underlayextenders), FALSE }, 
+  { "nounderlayextenders",movt_cboolproc, oo(movtstr,underlayextenders), FALSE },
   { "oldbeambreak",     opt_boolproc,   glob_oldbeambreak, TRUE },
   { "oldrestlevel",     opt_boolproc,   glob_oldrestlevel, TRUE },
   { "oldstemlength",    opt_boolproc,   glob_oldstemlength, TRUE },
@@ -2147,7 +2162,7 @@ static dirstr read_headlist[] = {
   { "playtranspose",    playtranspose,  0, 0 },
   { "playvolume",       playvolume,     0, 0 },
   { "pmwversion",       pmwversion,     0, 0 },
-  { "printkey",         printkey,       0, 0 }, 
+  { "printkey",         printkey,       0, 0 },
   { "printtime",        printtime,      0, 0 },
   { "psfooting",        movt_headproc,  oo(movtstr,footing), rh_footing+rh_ps },
   { "psheading",        movt_headproc,  oo(movtstr,heading), rh_heading+rh_ps },
@@ -2177,10 +2192,10 @@ static dirstr read_headlist[] = {
   { "stavesize",        stavesize,      0, 0 },
   { "stavesizes",       stavesize,      0, 0 },
   { "stavespacing",     stavespacing,   0, 0 },
-  { "stemlengths",      stemlengths,    0, 0 }, 
+  { "stemlengths",      stemlengths,    0, 0 },
   { "stemswap",         stemswap,       0, 0 },
   { "stemswaplevel",    stemswaplevel,  0, 0 },
-  { "stretchrule",      opt_intproc,    glob_stretchrule, int_u }, 
+  { "stretchrule",      opt_intproc,    glob_stretchrule, int_u },
   { "suspend",          movt_mapproc,   oo(movtstr,suspend), -1 },
   { "systemgap",        movt_intproc,   oo(movtstr,systemgap), int_u+int_f },
   { "textfont",         textfont,       0, 0 },
@@ -2199,7 +2214,7 @@ static dirstr read_headlist[] = {
   { "tripletfont",      movt_fontproc,  oo(movtstr,font_triplet),oo(fontsizestr,fontsize_triplet) },
   { "tripletlinewidth", movt_intproc,   oo(movtstr,tripletlinewidth), int_u+int_f },
   { "underlaydepth",    movt_intproc,   oo(movtstr,underlaydepth), int_f },
-  { "underlayextenders",movt_cboolproc, oo(movtstr,underlayextenders), TRUE }, 
+  { "underlayextenders",movt_cboolproc, oo(movtstr,underlayextenders), TRUE },
   { "underlaysize",     movt_fszproc,   oo(fontsizestr,fontsize_ulay), TRUE },
   { "underlaystyle",    movt_intproc,   oo(movtstr,underlaystyle), int_u },
   { "unfinished",       movt_cboolproc, oo(movtstr,unfinished), TRUE },
@@ -2214,12 +2229,12 @@ static int read_headsize = sizeof(read_headlist)/sizeof(dirstr);
 *              Read next heading directive       *
 *************************************************/
 
-/* 
+/*
 Arguments:    none
 Returns:      nothing
 */
 
-void 
+void
 next_heading(void)
 {
 dirstr *first, *last;
