@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2010 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: December 2010 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains part III of the code for reading in a PMW score file. It
@@ -643,12 +643,12 @@ for (;;)
           next_ch();
           if (read_ch == 'l' || read_ch == 'r')
             {
-            int s, x;
+            int sign, amount;
             int *a = (read_ch == 'l')? &slu : &sru;
             next_ch();
             if (read_ch == 'u' || read_ch == 'd')
               {
-              s = (read_ch == 'u')? +1 : -1;
+              sign = (read_ch == 'u')? +1 : -1;
               }
             else
               {
@@ -656,8 +656,8 @@ for (;;)
               break;
               }
             next_ch();
-            if (!read_expect_integer(&x, TRUE, FALSE)) break;
-            *a += s*x;
+            if (!read_expect_integer(&amount, TRUE, FALSE)) break;
+            *a += sign*amount;
             }
           else error_moan(37, "\"slu\", \"sld\", \"sru\" or \"srd\"");
           break;
