@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2009 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: January 2009 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains part IV of the code for reading in a PMW score file. It
@@ -201,7 +201,7 @@ stave_lastbasenoteptr = NULL;
 *                Assume                          *
 *************************************************/
 
-static char *assume_list[] = {
+static const char *assume_list[] = {
   "alto", "baritone", "bass", "contrabass", "deepbass", 
   "hclef", "key", "mezzo", "noclef", "soprabass", "soprano",
   "tenor", "time", "treble", "trebledescant", "trebletenor", 
@@ -210,7 +210,7 @@ static char *assume_list[] = {
 static void 
 p_assume(void)
 {
-int i;
+unsigned int i;
 read_word(read_stavedir);
 
 for (i = 0; i < (sizeof(assume_list)/sizeof(uschar *)); i++)
@@ -1008,7 +1008,7 @@ for (;;)
   int size = ff_offset_init;
 
   sigch();
-  if (read_ch != '\"' && (read_ch != 'd' || Ustrncmp(read_chptr, "raw ", 4 != 0)))
+  if (read_ch != '\"' && (read_ch != 'd' || Ustrncmp(read_chptr, "raw ", 4) != 0))
     break;
 
   p = store_Xget(sizeof(snamestr));
@@ -1491,7 +1491,6 @@ static void
 p_slur(void)
 {
 b_slurstr *p;
-BOOL control_point_moved = FALSE;
 int slurid = 0;
 int flags = read_dir->arg1;
 int ally = 0;
@@ -1565,7 +1564,6 @@ while (read_ch == '/')
     else if (read_ch == 'l' || read_ch == 'r')
       {
       BOOL left = read_ch == 'l';
-      control_point_moved = TRUE; 
       next_ch();
       if (read_ch == 'u' || read_ch == 'd' || read_ch == 'l' || read_ch == 'r')
         {
@@ -2153,7 +2151,8 @@ static void
 p_uolevel(void)
 {
 b_ulevelstr *p;
-int autoflag, value;
+int autoflag; 
+int value = 0;
 
 sigch();
 if (read_ch == '*')
