@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2012 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: January 2013 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains part V of the code for reading in a PMW score file - code
@@ -41,7 +41,7 @@ pitch relative to a stave, where 128 is the bottom line on the stave. This
 table is for "real" clefs only. */
 
 static uschar pitch_clef[] = { 64, 68, 72, 76, 80, 84, 84, 88, 92 };
-                          /* Tr  S   M   A   Te  cBa Ba  B   DB */
+                            /* Tr  S   M   A   Te  cBa Ba  B   DB */
 
 /* These tables give the extra "accidental left" amounts for accidentals in
 brackets */
@@ -106,7 +106,7 @@ return pitch_stave[pitch] + pitch_clef[stave_clef];
 Arguments:
   ax        address of the x movement, or NULL if not allowed
   ay        address of the y movement
-  af        address of the bflags field, or NULL if not allowed 
+  af        address of the bflags field, or NULL if not allowed
 
 Returns:    nothing
 */
@@ -124,33 +124,33 @@ while (read_ch == '/')
     {
     case 'u': *ay += read_movevalue(); break;
     case 'd': *ay -= read_movevalue(); break;
-    
+
     case 'l':
     case 'r':
     if (ax == NULL)
       error_moan(10, "/u or /d");
     else
       *ax += ((read_ch == 'r')?(+1):(-1)) * read_movevalue();
-    break;          
-    
+    break;
+
     default:
     if (af == NULL)
       error_moan(10, "/u, /d, /l, or /r");
     else switch (read_ch)
-      {  
-      case 'b': *af &= ~(DO_SBRA|DO_SKET); *af |= DO_RBRA | DO_RKET; break; 
+      {
+      case 'b': *af &= ~(DO_SBRA|DO_SKET); *af |= DO_RBRA | DO_RKET; break;
       case 'B': *af &= ~(DO_RBRA|DO_RKET); *af |= DO_SBRA | DO_SKET; break;
-      case '(': *af &= ~DO_SBRA; *af |= DO_RBRA; break;  
-      case '[': *af &= ~DO_RBRA; *af |= DO_SBRA; break;  
-      case ')': *af &= ~DO_SKET; *af |= DO_RKET; break;  
-      case ']': *af &= ~DO_RKET; *af |= DO_SKET; break;  
+      case '(': *af &= ~DO_SBRA; *af |= DO_RBRA; break;
+      case '[': *af &= ~DO_RBRA; *af |= DO_SBRA; break;
+      case ')': *af &= ~DO_SKET; *af |= DO_RKET; break;
+      case ']': *af &= ~DO_RKET; *af |= DO_SKET; break;
 
       default:
       error_moan(10, "/u, /d, /l, /r, /b, /B, /(, /), /[, or /]");
       break;
       }
     if (read_ch != '\\') next_ch();  /* \ means there was an error */
-    break;     
+    break;
     }
   }
 }
@@ -789,16 +789,16 @@ for (;;)
       acc = ac_dsharp;
       next_ch();
       break;
-      
+
       case '-':
       flags |= nf_halfacc;
       next_ch();
       /* Fall through */
-      
+
       default:
       acc = ac_sharp;
       break;
-      }             
+      }
     }
   else if (read_ch == '$')
     {
@@ -809,15 +809,15 @@ for (;;)
       acc = ac_dflat;
       next_ch();
       break;
-      
+
       case '-':
       flags |= nf_halfacc;
       next_ch();
       /* Fall through */
-      
+
       default:
       acc = ac_flat;
-      }             
+      }
     }
   else if (read_ch == '%') { acc = ac_natural; next_ch(); }
 
@@ -870,7 +870,7 @@ for (;;)
           int value = ((read_ch == 'o')? or_dsharp : or_accbelow);
           next_ch();
           ornmove(&(p->x), &(p->y), NULL);
-          p->bflags = 0; 
+          p->bflags = 0;
           if (read_ch == ')') { value += 1; next_ch(); }
             else if (read_ch == ']') { value += 2; next_ch(); }
           p->ornament = value;
@@ -1058,28 +1058,28 @@ TRANSPOSE:
         transposedaccforce, acc_onenote, FALSE, tiedcount);
       this_tiedata[chordcount].acc_tp = baraccs_tp[pitch];
       }
-      
-    /* If there was a half-accidental that is now a natural, change it to the 
-    opposite half-accidental, and play similar games with double sharps and 
+
+    /* If there was a half-accidental that is now a natural, change it to the
+    opposite half-accidental, and play similar games with double sharps and
     flats. */
-    
+
     if ((flags & nf_halfacc) != 0)
       {
       if (acc == ac_none || acc == ac_natural)
-        acc = ((orig & 0x0f) == ac_sharp)? ac_flat : ac_sharp; 
+        acc = ((orig & 0x0f) == ac_sharp)? ac_flat : ac_sharp;
       else if (acc == ac_dflat)
         {
         acc = ac_sharp;
         pitch -= 2;
         abspitch -= 2;
-        }        
+        }
       else if (acc == ac_dsharp)
         {
         acc = ac_flat;
         pitch += 2;
-        abspitch += 2;   
-        }     
-      }   
+        abspitch += 2;
+        }
+      }
 
     /* Adjust absolute pitch for transposing clefs */
 
@@ -1127,12 +1127,12 @@ TRANSPOSE:
   /* If the accidental is to be printed above or below, add in its value, which
   is not known till after transposition. */
 
-  if (acc_above != NULL) 
+  if (acc_above != NULL)
     {
     *acc_above += 3*(acc - 1);
     if ((flags & nf_halfacc) != 0)
-      *acc_above += (acc == ac_sharp)? 6 : 12;  
-    } 
+      *acc_above += (acc == ac_sharp)? 6 : 12;
+    }
 
   /* If the accidental is invisible, cancel it now that the true pitch has been
   determined. */
@@ -1141,11 +1141,11 @@ TRANSPOSE:
 
   /* Note or rest length adjustment by modifiers */
 
-  if (read_ch == '!' && pitch == 0)
+  if (read_ch == '!')
     {
     notetype = semibreve;
     length = stave_requiredbarlength;
-    flags |= nf_centre;
+    if (pitch == 0) flags |= nf_centre;
     next_ch();
     }
   else
@@ -1250,12 +1250,12 @@ TRANSPOSE:
 
     while (read_ch != '\\' && read_ch != EOF)
       {
-      accent *ap; 
+      accent *ap;
       switch (read_ch)
         {
 
         /* ----- Handle things that are not accents or ornaments ----- */
-         
+
         case ':':
         next_ch();
         if (read_ch == ':')
@@ -1265,7 +1265,7 @@ TRANSPOSE:
           }
         else flags ^= nf_lowdot;
         break;
-        
+
         case 'c':
         next_ch();
         explicit_couple = nf_couple;
@@ -1369,14 +1369,14 @@ TRANSPOSE:
         else if (read_ch == 'm')
           {
           next_ch();
-          flags |= nf_smallhead;  
-          }     
+          flags |= nf_smallhead;
+          }
         else if (read_ch == 'p')   /* sp is an ornament */
           {
           read_ch = 's';
           read_chptr--;
           goto ACCORN;
-          }    
+          }
         else
           {
           error_moan(10, "su, sd, sw, sl, sm, or sp");  /* skips to '\' or EOL */
@@ -1391,25 +1391,25 @@ TRANSPOSE:
         break;
 
         /* ----- Handle accents and ornaments ----- */
-        
+
         default:
         ACCORN:
         for (ap = accent_chars; ap->string != NULL; ap++)
           {
-          int i; 
+          int i;
           int ln = (int)Ustrlen(ap->string);
           for (i = 0; i < ln; i++)
             if (read_chptr[i-1] != ap->string[i]) break;
           if (i >= ln)
             {
             read_chptr += ln - 1;
-            next_ch(); 
-            break; 
-            }  
+            next_ch();
+            break;
+            }
           }
 
         /* Found in the table */
-         
+
         if (ap->string != NULL)
           {
           if (ap->flag < 256)     /* Ornaments */
@@ -1420,74 +1420,74 @@ TRANSPOSE:
               case or_dmord:
               case or_imord:
               case or_dimord:
-              case or_turn:      
-              case or_iturn: 
+              case or_turn:
+              case or_iturn:
               if ((ornset & ornset_mordturn) != 0)
                 error_moan(45);   /* But carry on */
               else ornset |= ornset_mordturn;
               break;
-              
+
               case or_trem1:
               case or_trem2:
               case or_trem3:
               if ((ornset & ornset_trem) != 0)
                 error_moan(45);   /* But carry on */
               else ornset |= ornset_trem;
-              break;         
-              
+              break;
+
               case or_tr:
               case or_trsh:
               case or_trfl:
-              case or_trnat:    
+              case or_trnat:
               if ((ornset & ornset_trill) != 0)
                 error_moan(45);   /* But carry on */
               else ornset |= ornset_trill;
               break;
               }
-              
+
             if (chordcount == 0)
               {
               b_ornamentstr *p = store_getitem(b_ornament);
               if (last_note_ornament == NULL) last_note_ornament = p;
-              p->ornament = ap->flag; 
-              p->bflags = 0; 
-              
+              p->ornament = ap->flag;
+              p->bflags = 0;
+
               /* Tremolos have no horizontal movement or bracketing; arpeggios
-              and spread have no bracketing, but can have arbitrary movement. 
+              and spread have no bracketing, but can have arbitrary movement.
               Because tremelos use '/' as their character, the coding is
               messy. */
-                
+
               if (ap->flag >= or_trem1 && ap->flag <= or_trem3)
                 {
                 p->x = 0;            /* No horizontal movement */
                 p->y = 0;            /* Default no vertical movement */
                 p->bflags = 0;       /* No bracketing */
                 ornament = -1;       /* Cancel auto tremolo */
-               
+
                 if (read_ch == '/')                /* Move a trem3 */
                   ornmove(NULL, &(p->y), NULL);
                 else if (ap->flag != or_trem1 &&   /* Move a trem1/trem2 */
                          (read_ch == 'u' || read_ch == 'd') &&
                          (read_chptr < read_endptr) &&
-                         (isdigit(*read_chptr) || *read_chptr == '-')) 
+                         (isdigit(*read_chptr) || *read_chptr == '-'))
                   {
-                  p->ornament -= 1; 
+                  p->ornament -= 1;
                   read_ch = '/';
-                  read_chptr--;  
+                  read_chptr--;
                   ornmove(NULL, &(p->y), NULL);
-                  } 
-                }  
-              else ornmove(&(p->x), &(p->y), 
+                  }
+                }
+              else ornmove(&(p->x), &(p->y),
                 (ap->flag >= or_arp)? NULL : &(p->bflags));
-              }  
+              }
             else error_moan(48, "Ornaments");
-            } 
-            
+            }
+
           else    /* Accents */
             {
             if (chordcount == 0)
               {
-              int i; 
+              int i;
               acflags |= ap->flag;
               for (i = 1; i <= dyn_max; i++)
                 {
@@ -1496,11 +1496,11 @@ TRANSPOSE:
                   dynmove(i-1);
                   break;
                   }
-                }        
+                }
               }
-            else error_moan(48, "Accents");     
-            } 
-          }  
+            else error_moan(48, "Accents");
+            }
+          }
 
         /* Not found in the big table; check for a<n>. */
 
@@ -1511,25 +1511,25 @@ TRANSPOSE:
           if (read_expect_integer(&x, FALSE, FALSE))
             {
             if (chordcount == 0)
-              {  
+              {
               if (x <= dyn_max)
-                { 
+                {
                 acflags |= accent_list[x];
-                dynmove(x-1); 
-                } 
+                dynmove(x-1);
+                }
               else error_moan(128, x);
               }
-            else error_moan(48, "Accents");    
+            else error_moan(48, "Accents");
             }
           }
 
         /* Unknown */
-         
+
         else { error_moan(45); next_sigch(); }
         }
 
       if ((acflags & (af_staccato|af_staccatiss)) ==
-        (af_staccato|af_staccatiss)) error_moan(129);    
+        (af_staccato|af_staccatiss)) error_moan(129);
       sigch();
       }                            /* end of loop */
 
@@ -1542,11 +1542,11 @@ TRANSPOSE:
 
   if (pitch == 0 && ((ornset != 0 && (flags & nf_hidden) == 0) ||
     acc != 0 || (acflags & af_dynamics) != 0)) error_moan(68);
-    
+
   /* A small notehead may not be specified for a grace note. */
-  
-  if (length == 0 && (flags & nf_smallhead) != 0) error_moan(108); 
-    
+
+  if (length == 0 && (flags & nf_smallhead) != 0) error_moan(108);
+
   /* Accumulate bar length and check that chord notes are all same length. If
   not, and the current one is a crotchet (i.e. just a lower case letter) force
   it to be the same as the first note. Other lengths cause an error. Output an
