@@ -229,7 +229,6 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
 
   if (another && out_sysblock->stavespacing[out_stave] > 0)
     {
-    int i;
     for (i = out_stave + 1; i <= out_laststave; i++)
       {
       stavestr *sss;
@@ -369,10 +368,10 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
     bar_cont->slurs = NULL;
     while (s != NULL)
       {
-      slurstr *ss = s->next;
+      slurstr *snext = s->next;
       misc_drawslur(s, true_endline - 3000 + curmovt->endlinesluradjust, 0,
         TRUE);
-      s = ss;
+      s = snext;
       }
 
     /* Draw ties and glissandos to line end. For glissandos, invent a
@@ -400,20 +399,20 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
 
           if (out_bar < curmovt->barcount)
             {
-            stavestr *ss = curmovt->stavetable[out_stave];
-            bstr *p = (ss == NULL)? NULL : ss->barindex[out_bar+1];
+            stavestr *st = curmovt->stavetable[out_stave];
+            bstr *pp = (st == NULL)? NULL : st->barindex[out_bar+1];
 
-            if (p != NULL)
+            if (pp != NULL)
               {
-              int type = p->type;
+              int type = pp->type;
               while (type != b_End)
                 {
                 if (type == b_Jump)
-                  p = (bstr *)(((b_Jumpstr *)p)->next);
+                  pp = (bstr *)(((b_Jumpstr *)pp)->next);
 
                 else if (type == b_note)
                   {
-                  b_notestr *tp = (b_notestr *)p;
+                  b_notestr *tp = (b_notestr *)pp;
                   do
                     {
                     notelist[count++] = tp;
@@ -423,8 +422,8 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
                   break;
                   }
 
-                p = (bstr *)((uschar *)p + length_table[type]);
-                type = p->type;
+                pp = (bstr *)((uschar *)pp + length_table[type]);
+                type = pp->type;
                 }
               }
             }
@@ -439,11 +438,11 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
 
       if ((flags & tief_gliss) != 0 && n_chordcount == 1)
         {
-        b_notestr *p =
+        b_notestr *pp =
           (ss == NULL)? NULL : (b_notestr *)(ss->barindex[out_bar+1]);
-        if (p != NULL && p->type != b_note) p = misc_nextnote(p, NULL);
-        if (p == NULL) n_pitch = (n_pitch > P_3L)? P_0S : P_5S;
-          else n_pitch = p->spitch;
+        if (pp != NULL && pp->type != b_note) pp = misc_nextnote(pp, NULL);
+        if (pp == NULL) n_pitch = (n_pitch > P_3L)? P_0S : P_5S;
+          else n_pitch = pp->spitch;
         out_glissando(x + (45*main_stavemagn)/10, flags);
         }
       }
@@ -551,22 +550,22 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
 
         if (out_bar < curmovt->barcount)
           {
-          stavestr *ss = curmovt->stavetable[out_stave];
-          bstr *p = (ss == NULL)? NULL : ss->barindex[out_bar+1];
+          stavestr *st = curmovt->stavetable[out_stave];
+          bstr *pp = (st == NULL)? NULL : st->barindex[out_bar+1];
 
-          if (p != NULL)
+          if (pp != NULL)
             {
-            int type = p->type;
+            int type = pp->type;
             while (type != b_End)
               {
               if (type == b_Jump)
-                p = (bstr *)(((b_Jumpstr *)p)->next);
+                pp = (bstr *)(((b_Jumpstr *)pp)->next);
 
               /* Note or chord => extender continues (unless rest) */
 
               else if (type == b_note)
                 {
-                extender_continues = ((b_notestr *)p)->spitch != 0;
+                extender_continues = ((b_notestr *)pp)->spitch != 0;
                 break;
                 }
 
@@ -575,7 +574,7 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
 
               else if (type == b_text)
                 {
-                b_textstr *t = (b_textstr *)p;
+                b_textstr *t = (b_textstr *)pp;
                 if ((t->flags & text_ul) != 0)
                   {
                   extender_continues = ((t->string)[0] == '=');
@@ -585,8 +584,8 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
 
               /* Next item in the bar */
 
-              p = (bstr *)((uschar *)p + length_table[type]);
-              type = p->type;
+              pp = (bstr *)((uschar *)pp + length_table[type]);
+              type = pp->type;
               }
             }
           }
@@ -625,15 +624,15 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
 
   if (out_manyrest > 1)
     {
-    bstr *p = (ss == NULL)? NULL : ss->barindex[out_bar+out_manyrest-1];
+    bstr *pp = (ss == NULL)? NULL : ss->barindex[out_bar+out_manyrest-1];
 
-    if (p != NULL)
+    if (pp != NULL)
       {
-      int type = p->type;
+      int type = pp->type;
       while (type != b_End)
         {
         if (type == b_Jump)
-          p = (bstr *)(((b_Jumpstr *)p)->next);
+          pp = (bstr *)(((b_Jumpstr *)pp)->next);
 
         else if (type == b_dbar) out_barchar = bar_double;
 
@@ -648,11 +647,11 @@ for (out_stave = out_laststave; out_stave >= 0; out_stave--)
 
         else if (type == b_clef || type == b_ibar)
           {
-          out_setother(p);
+          out_setother(pp);
           }
 
-        p = (bstr *)((uschar *)p + length_table[type]);
-        type = p->type;
+        pp = (bstr *)((uschar *)pp + length_table[type]);
+        type = pp->type;
         }
       }
     }
