@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2013 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: March 2013 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains code for setting up and outputting beams */
@@ -1137,6 +1137,7 @@ for (i = 0; i < 2; i++)
 
   else
     {
+    int abs_slope; 
     int slope = findslope();
     int yslope = beam_firstY + mac_muldiv(slope, xright-beam_firstX, 1000);
 
@@ -1153,8 +1154,9 @@ for (i = 0; i < 2; i++)
     keep the slope down to a smaller maximum to enable more cases to be fitted
     in without retries. */
 
-    if (lastopposite && abs(beam_slope) > 200)
-      beam_slope = mac_muldiv(beam_slope, 200, abs(beam_slope));
+    abs_slope = abs(beam_slope); 
+    if (lastopposite && abs_slope > 200)
+      beam_slope = mac_muldiv(beam_slope, 200, abs_slope);
     }
 
   /* Inner loop for retrying with a smaller maximum slope when we fail to find
@@ -1176,14 +1178,14 @@ for (i = 0; i < 2; i++)
 
   if (offsetOK) break; else
     {
-    b_notestr *p = beam_first;
+    b_notestr *bfp = beam_first;
     int flag = beam_upflag? nf_stemup : 0;
 
     for (;;)
       {
-      if ((p->flags & nf_stemup) != flag) read_resetstemflag(p, flag);
-      if (p == beam_last) break;
-      p = misc_nextnote(p, NULL);
+      if ((bfp->flags & nf_stemup) != flag) read_resetstemflag(bfp, flag);
+      if (bfp == beam_last) break;
+      bfp = misc_nextnote(p, NULL);
       }
 
     error_moan(61, out_bar, out_stave);
@@ -1216,10 +1218,10 @@ left is drawn. */
 
 if (beam_continued)
   {
-  int adjust = 4 * main_stavemagn;
-  if (beam_upflag) adjust += beam_Xcorrection;
-  beam_firstX -= adjust;
-  beam_firstY -= (beam_slope * adjust) / 1000;
+  int beamadjust = 4 * main_stavemagn;
+  if (beam_upflag) beamadjust += beam_Xcorrection;
+  beam_firstX -= beamadjust;
+  beam_firstY -= (beam_slope * beamadjust) / 1000;
 
   longestnote = (bar_cont->overbeam)->longestnote;
   if (beam_count == 1) rightbreak2 = TRUE;
