@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2013 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: March 2013 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains the main code typesetting one note or chord */
@@ -56,7 +56,6 @@ Returns:   pointer after the last note
 bstr *
 out_setnote(b_notestr *p)
 {
-int i;
 int accleftnum = 0;
 
 DEBUG(("out_setnote() start\n"));
@@ -353,10 +352,14 @@ else
         mac_muldiv(longrest_widths[i], main_stavemagn, 1000))/2;
     
       if (matrix != NULL) memcpy(font_transform, matrix, 4*sizeof(int));
- 
+      
+      /* Remember the mid-point where the long rest count is output to make
+      it easier to draw a suitable sign when the bar is wide or narrow. */
+      
+      n_longrestmid = out_Xadjustment + (leftx + out_barlinex)/2;  
       sprintf(CS s, "%d", out_manyrest);
-      out_string(s, font, size, out_Xadjustment + 
-        (leftx + out_barlinex - font_stringwidth(s, font, size))/2,
+      out_string(s, font, size, n_longrestmid - 
+        (font_stringwidth(s, font, size))/2,
           out_ystave - 18*main_stavemagn - out_Yadjustment, 0);
       font_reset();
       }
@@ -771,6 +774,7 @@ afterwards, for the benefit of end-of-bar text. They are initially cleared at
 the start of a bar. */
 
   {
+  int i; 
   int save_flags = n_flags;
   int save_acflags = n_acflags; 
   n_flags = n_chordflags;
@@ -790,6 +794,7 @@ the start of a bar. */
 
 if (out_drawqueueptr > 0)
   {
+  int i; 
   draw_ox = n_x + n_cueadjust;  /* Set origin */
   draw_oy = 0;
   for (i = 0; i < out_drawqueueptr; i++)
