@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2008 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: October 2008 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains code for miscellanous functions used
@@ -1000,6 +1000,7 @@ out_slur(int ix0, int iy0, int ix1, int iy1, int flags, int co, int start,
 int x[10], y[10], cc[10];
 int above, wiggly, ed_adjust;
 double zz[4];
+double temp;
 double xx, yy, w, v;
 double x0, x1, x2, x3, y0, y1, y2, y3;
 double ax, ay, bx, by, cx, cy, f, g;
@@ -1081,10 +1082,12 @@ if (v > 10000.0) v = 10000.0;
 
 /* It is necessary to use floor() in the conversion of xx*0.3 to an integer in
 the next statement in order to get the same value under valgrind. We know that
-xx is positive, so we don't need to test whether to use floor() or ceil(). */
+xx is positive, so we don't need to test whether to use floor() or ceil(). 
+Using the (int) cast only on a variable (not on a function) avoids a compiler 
+warning. */
 
-co = (above * (co + ((xx > 20000)?
-  6000 : (int)(floor(xx * 0.3)))) * main_stavemagn)/1000;
+temp = floor(xx * 0.3);
+co = (above * (co + ((xx > 20000)? 6000 : (int)temp)) * main_stavemagn)/1000;
   
 f = ((double)start)/1000.0;
 g = ((double)stop)/1000.0;
@@ -1127,17 +1130,22 @@ if (g > 0.0 && g < 1.0) g = bezfraction(g, ax, bx, cx, x0, x3);
 that we want, and set up the first path to be that portion. We used to compute 
 the x values with just an (int) cast, but this gave slightly different values 
 under valgrind. Using floor() or ceil() with a rounding value solves that 
-problem. */
+problem. We must also avoid using an (int) cast directly on these functions, 
+because it provokes a compiler warning when -Wbad-function-cast is set. */
 
 zz[0] = x0 + ((ax*f + bx)*f + cx)*f;
 zz[1] = x0 + (((3.0*ax*g + bx)*f + 2.0*(bx*g + cx))*f + cx*g)/3.0;
 zz[2] = x0 + (((3.0*ax*g + 2.0*bx)*g + cx)*f + 2.0*cx*g + bx*g*g)/3.0;
 zz[3] = x0 + ((ax*g + bx)*g + cx)*g;
 
-x[0] = (zz[0] >= 0.0)? (int)(floor(zz[0] + 0.0001)) : (int)(ceil(zz[0] - 0.0001));
-x[1] = (zz[1] >= 0.0)? (int)(floor(zz[1] + 0.0001)) : (int)(ceil(zz[1] - 0.0001));
-x[2] = (zz[2] >= 0.0)? (int)(floor(zz[2] + 0.0001)) : (int)(ceil(zz[2] - 0.0001));
-x[3] = (zz[3] >= 0.0)? (int)(floor(zz[3] + 0.0001)) : (int)(ceil(zz[3] - 0.0001));
+temp = (zz[0] >= 0.0)? floor(zz[0] + 0.0001) : ceil(zz[0] - 0.0001);
+x[0] = (int)temp;
+temp = (zz[1] >= 0.0)? floor(zz[1] + 0.0001) : ceil(zz[1] - 0.0001);
+x[1] = (int)temp;
+temp = (zz[2] >= 0.0)? floor(zz[2] + 0.0001) : ceil(zz[2] - 0.0001);
+x[2] = (int)temp;
+temp = (zz[3] >= 0.0)? floor(zz[3] + 0.0001) : ceil(zz[3] - 0.0001);
+x[3] = (int)temp;
 
 /* Now do exactly the same for the y points */
 
@@ -1150,10 +1158,14 @@ zz[1] = y0 + (((3.0*ay*g + by)*f + 2.0*(by*g + cy))*f + cy*g)/3.0;
 zz[2] = y0 + (((3.0*ay*g + 2.0*by)*g + cy)*f + 2.0*cy*g + by*g*g)/3.0;
 zz[3] = y0 + ((ay*g + by)*g + cy)*g;
 
-y[0] = (zz[0] >= 0.0)? (int)(floor(zz[0] + 0.0001)) : (int)(ceil(zz[0] - 0.0001));
-y[1] = (zz[1] >= 0.0)? (int)(floor(zz[1] + 0.0001)) : (int)(ceil(zz[1] - 0.0001));
-y[2] = (zz[2] >= 0.0)? (int)(floor(zz[2] + 0.0001)) : (int)(ceil(zz[2] - 0.0001));
-y[3] = (zz[3] >= 0.0)? (int)(floor(zz[3] + 0.0001)) : (int)(ceil(zz[3] - 0.0001));
+temp = (zz[0] >= 0.0)? floor(zz[0] + 0.0001) : ceil(zz[0] - 0.0001);
+y[0] = (int)temp;
+temp = (zz[1] >= 0.0)? floor(zz[1] + 0.0001) : ceil(zz[1] - 0.0001);
+y[1] = (int)temp;
+temp = (zz[2] >= 0.0)? floor(zz[2] + 0.0001) : ceil(zz[2] - 0.0001);
+y[2] = (int)temp;
+temp = (zz[3] >= 0.0)? floor(zz[3] + 0.0001) : ceil(zz[3] - 0.0001);
+y[3] = (int)temp;
 
 cc[0] = path_move;
 cc[1] = path_curve;
@@ -1179,11 +1191,11 @@ if ((flags & sflag_i) != 0)
 
   for (t = 0.0; t < 1.04; t += 0.05)
     {
-    double xx = ((ax*t + bx)*t + cx)*t + x0;
-    double yy = ((ay*t + by)*t + cy)*t + y0;
-    dlength += sqrt((xx-xp)*(xx-xp) + (yy-yp)*(yy-yp));
-    xp = xx;
-    yp = yy;
+    double xxc = ((ax*t + bx)*t + cx)*t + x0;
+    double yyc = ((ay*t + by)*t + cy)*t + y0;
+    dlength += sqrt((xxc-xp)*(xxc-xp) + (yyc-yp)*(yyc-yp));
+    xp = xxc;
+    yp = yyc;
     }
   length = (int)dlength;
 
@@ -1280,16 +1292,16 @@ portion. */
 
 if ((flags & sflag_e) != 0 && start < 500 && stop > 500)
   {
-  int xx, yy;
+  int xxm, yym;
   double dx, dy, theta, cs, sn;
 
   /* Calculate the midpoint of the curve from the parametric equations taking
   t = 0.5, and also calculate the slope at that point. */
 
-  xx = (int)(((ax*0.5 + bx)*0.5 + cx)*0.5 - w);
+  xxm = (int)(((ax*0.5 + bx)*0.5 + cx)*0.5 - w);
   dx = (3.0*ax*0.5 + 2.0*bx)*0.5 + cx;
 
-  yy = (int)(((ay*0.5 + by)*0.5 + cy)*0.5);
+  yym = (int)(((ay*0.5 + by)*0.5 + cy)*0.5);
   dy = (3.0*ay*0.5 + 2.0*by)*0.5 + cy;
 
   /* Draw the editorial mark. Translate and rotate gave rounding errors, so do
@@ -1301,17 +1313,17 @@ if ((flags & sflag_e) != 0 && start < 500 && stop > 500)
 
   if (above > 0)
     {
-    x[0] = xx - (int)((2000.0+(double)ed_adjust)*sn);
-    y[0] = yy + (int)((2000.0+(double)ed_adjust)*cs);
-    x[1] = xx + (int)(2000.0*sn);
-    y[1] = yy - (int)(2000.0*cs);
+    x[0] = xxm - (int)((2000.0+(double)ed_adjust)*sn);
+    y[0] = yym + (int)((2000.0+(double)ed_adjust)*cs);
+    x[1] = xxm + (int)(2000.0*sn);
+    y[1] = yym - (int)(2000.0*cs);
     }
   else
     {
-    x[0] = xx - (int)(2000.0*sn);
-    y[0] = yy + (int)(2000.0*cs);
-    x[1] = xx + (int)((2000.0+(double)ed_adjust)*sn);
-    y[1] = yy - (int)((2000.0+(double)ed_adjust)*cs);
+    x[0] = xxm - (int)(2000.0*sn);
+    y[0] = yym + (int)(2000.0*cs);
+    x[1] = xxm + (int)((2000.0+(double)ed_adjust)*sn);
+    y[1] = yym - (int)((2000.0+(double)ed_adjust)*cs);
     }
 
   cc[0] = path_move;
