@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2013 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: January 2013 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains the code for generating an image of one individual note
@@ -27,10 +27,10 @@ static uschar common[] = {
 static uschar *reststrings[] = {
   US"*", US"+", US",", US"-", US".", US"z.w{{y.",
   US"zzx.w{{y.w{{y.", US"zzzx.w{{y.w{{y.w{{y." };
-  
+
 static uschar *multireststrings[] = {  /* Start for 2, last is for 8 */
-  US"*", US"*z+", US"*{{w*", US"*{{w*xz+", US"*{{w*xz*", 
-  US"*{{w*xz*z+", US"*{{w*xz*{{w*" };  
+  US"*", US"*z+", US"*{{w*", US"*{{w*xz+", US"*{{w*xz*",
+  US"*{{w*xz*z+", US"*{{w*xz*{{w*" };
 
 static uschar *tailstrings[] = {
   US"",  US"",       US"",            US"",
@@ -83,7 +83,7 @@ static int outdynybadjusts[] = { -4000, 0, -1500, 0, -1000, -1000 };
 are not straightforward, and have individual code. Note that characters greater
 than 127 must be represented as UTF-8. */
 
-static char *ornament_strings[] = {
+static const char *ornament_strings[] = {
 /* ferm  tr  trsh trfl trnat trem1 trem2 trem3 */
     "",  "",  "",  "",  "",   "",   "",   "",
 /* mord  dmord  imord dimord turn iturn arp arpu arpd spread */
@@ -124,11 +124,11 @@ static int ornament_xadjusts[] = {
 /* Amount by which to adjust the brackets when bracketing */
 
 static int ornament_yaadjusts[] = {
-  0, 
+  0,
   -1000,     /* Trill */
-  -4000, 
-  -4000, 
-  -4000, 
+  -4000,
+  -4000,
+  -4000,
   0, 0, 0,
   0, 0, -2000, -2000, -1000, -1000, 0, 0, 0, 0,
   1000, 2000, 2000,  /* dsharps */
@@ -143,11 +143,11 @@ static int ornament_yaadjusts[] = {
 };
 
 static int ornament_ybadjusts[] = {
-  0, 
+  0,
   -1000,     /* Trill */
-  2000, 
-  2000, 
-  2000, 
+  2000,
+  2000,
+  2000,
   0, 0, 0,
   0, 0, 2000, 2000, 1000, 1000, 0, 0, 0, 0,
   0,     -3000, -3000,  /* dsharps */
@@ -264,7 +264,7 @@ static BOOL
 show_note(int x)
 {
 uschar buff[100];
-uschar *p = buff;
+uschar *p;
 BOOL ledgered = FALSE;
 BOOL inverted = (n_flags & nf_invert) != 0;
 int top = P_6L;
@@ -309,7 +309,7 @@ if (n_pitch <= bot && out_stavelines >= 5 && bar_cont->noteheadstyle != nh_none)
   yy = out_ystave - (bot - 130)*main_stavemagn - n_pcorrection;
   if (n_fontsize == 10000 && !inverted)
     {
-    uschar *p = buff;
+    p = buff;
     while (n_pitch <= bot)
       {
       *p++ = curmovt->ledger;
@@ -323,8 +323,8 @@ if (n_pitch <= bot && out_stavelines >= 5 && bar_cont->noteheadstyle != nh_none)
     }
   else  /* Have to position each line separately */
     {
-    uschar *p = buff;
     int yyy = yy;
+    p = buff;
     *p++ = curmovt->ledger;
     if (inverted)
       {
@@ -369,7 +369,7 @@ else if (n_pitch >= top && out_stavelines >= 5 &&
   yy = out_ystave - (top - 130)*main_stavemagn - n_pcorrection;
   if (n_fontsize == 10000 && !inverted)
     {
-    uschar *p = buff;
+    p = buff;
     while (n_pitch >= top)
       {
       *p++ = curmovt->ledger;
@@ -383,8 +383,8 @@ else if (n_pitch >= top && out_stavelines >= 5 &&
     }
   else
     {
-    uschar *p = buff;
     int yyy = yy;
+    p = buff;
     *p++ = curmovt->ledger;
     if (inverted)
       {
@@ -416,6 +416,7 @@ else if (n_pitch >= top && out_stavelines >= 5 &&
 /* Optimize the common case where there is a complete character available in
 the music font. */
 
+p = buff;
 if (n_notetype < dsquaver && n_stemlength == 0 &&
   bar_cont->noteheadstyle == nh_normal &&
     (n_flags & (nf_invert|nf_stem|nf_smallhead)) == nf_stem)
@@ -656,17 +657,62 @@ else yoffset += 4000 + n_pcorrection;
 
 y = out_ystave - (yoffset*main_stavemagn)/1000;
 
+/* Output a normal rest */
+
 if (notetype >= 0)
   ps_musstring(reststrings[n_notetype], fontsize, x, y);
 
+/* Output a coded multirest */
+
 else if (curmovt->codemultirests && out_manyrest < 9)
   {
- 
   ps_musstring(multireststrings[out_manyrest - 2], fontsize, x, y - 2000);
+  }
+  
+/* Output a |----| long rest sign. If the bar is unusually long or unusually
+short, draw the long rest symbol; note that ps_line() works in conventional
+coordinates relative to the base line of the stave. The variable n_longrestmid 
+contains the mid-point of the long rest. */
+  
+else
+  {
+  int wide; 
+  int rs = out_barlinex - n_longrestmid;
+    
+  if ((wide = rs > 40*main_stavemagn) || x - out_barx < 6000)
+    {
+    posstr *p;
+    int xl, xr;
+    int vthick = (3*main_stavemagn)/10;
+    int hthick = 3*main_stavemagn;  
+    int adjust = 0;
+    int min = wide? 15000 : 12000; 
+    
+    /* Calculate an adjustment for anything at the end of the bar, e.g. a clef 
+    change. */
+    
+    for (p = out_posptr + 1; p->moff <= 0; p++); /* Skip preceding */
+    for (; p < out_poslast; p++)
+      adjust += p[1].xoff - p->xoff;
 
+    /* Place the right hand end with respect to the the barline, nearer for a 
+    narrow bar, then place the left hand end symmetrically. */
+
+    if (adjust < min) adjust = min + adjust/3;
+      else adjust += 5000;
+    
+    xr = out_barlinex - mac_muldiv(adjust, main_stavemagn, 1000);
+    xl = 2*n_longrestmid - xr;
+
+    ps_line(xl, 8*main_stavemagn, xr, 8*main_stavemagn, hthick, 0);
+    ps_line(xl, 4*main_stavemagn, xl, 12*main_stavemagn, vthick, 0);
+    ps_line(xr, 4*main_stavemagn, xr, 12*main_stavemagn, vthick, 0);
+    }
+  
+  /* Use the long rest character */
+  
+  else ps_muschar(x, y, mc_longrest, fontsize);
   } 
-
-else ps_muschar(x, y, mc_longrest, fontsize);
 }
 
 
@@ -684,7 +730,7 @@ void
 out_shownote(void)
 {
 int fontsize = (n_fontsize*main_stavemagn)/1000;
-int x = n_x + n_cueadjust;
+int xn = n_x + n_cueadjust;
 int yyabove, yybelow;
 int acc_level, acc_upflag;
 BOOL ledgered = FALSE;
@@ -697,7 +743,7 @@ if ((bar_cont->flags & cf_notes) != 0 && (n_flags & nf_hidden) == 0)
   {
   /* If printing a breve, move left to align with semibreve position */
 
-  if (n_pitch != 0 && n_notetype == breve) x -= (23*main_stavemagn)/10;
+  if (n_pitch != 0 && n_notetype == breve) xn -= (23*main_stavemagn)/10;
 
   /* First, any accidental is set, prior to the given position */
 
@@ -711,7 +757,7 @@ if ((bar_cont->flags & cf_notes) != 0 && (n_flags & nf_hidden) == 0)
       offset += ((n_acc == ac_sharp)? (curmovt->hsharpstyle == 0) :
         (curmovt->hflatstyle == 0))? 18:36;
       }
-    ps_muschar(x - mac_muldiv(n_accleft, n_fontsize, 10000),
+    ps_muschar(xn - mac_muldiv(n_accleft, n_fontsize, 10000),
       out_ystave - (n_pitch - 130)*main_stavemagn - n_pcorrection,
         out_acctable[offset], fontsize);
      }
@@ -726,9 +772,9 @@ if ((bar_cont->flags & cf_notes) != 0 && (n_flags & nf_hidden) == 0)
       notetype = -1;
       n_flags &= ~(nf_dot+nf_plus);   /* Kill dots for many bar rest */
       }
-    show_rest(x, notetype);
+    show_rest(xn, notetype);
     }
-  else ledgered = show_note(x);
+  else ledgered = show_note(xn);
 
   /* Deal with horizontal dots/plus - fudge for quavers and breves */
 
@@ -775,10 +821,10 @@ if ((bar_cont->flags & cf_notes) != 0 && (n_flags & nf_hidden) == 0)
     /* Output the dot(s) */
 
     ps_musstring(((n_flags & nf_plus) == 0)? US"?" : US"\302\207", fontsize,
-      x + dotpos, out_ystave - dotlevel - n_pcorrection);
+      xn + dotpos, out_ystave - dotlevel - n_pcorrection);
 
     if ((n_flags & nf_dot2) != 0)
-      ps_musstring(US"?", fontsize, x + dotpos + (35*main_stavemagn)/10,
+      ps_musstring(US"?", fontsize, xn + dotpos + (35*main_stavemagn)/10,
         out_ystave - dotlevel - n_pcorrection);
     }
   }
@@ -876,7 +922,7 @@ if ((n_acflags & af_dyninside) != 0)
 
   if ((n_acflags & af_staccato) != 0)
     {
-    show_brack_acc(US">", fontsize, x + out_dynmovex[dyn_staccato],
+    show_brack_acc(US">", fontsize, xn + out_dynmovex[dyn_staccato],
       out_ystave - p - out_dynmovey[dyn_staccato], out_dynmovef[dyn_staccato],
       acc_upflag? 4*main_stavemagn:(-4)*main_stavemagn,
       -4*main_stavemagn, 0, 0);
@@ -894,7 +940,7 @@ if ((n_acflags & af_dyninside) != 0)
     int pp = (acc_upflag? 25:55)*main_stavemagn/10;
     if (acc_upflag != n_upflag) pp += (acc_upflag? 1:-1)*main_stavemagn;
     show_brack_acc(acc_upflag? US"\303\203":US"\303\202", fontsize,
-      x + out_dynmovex[dyn_staccatiss],
+      xn + out_dynmovex[dyn_staccatiss],
       out_ystave - p - pp - out_dynmovey[dyn_staccatiss],
       out_dynmovef[dyn_staccatiss],
       acc_upflag? 3*main_stavemagn:(-3)*main_stavemagn, 0, 0, 0);
@@ -921,7 +967,7 @@ if ((n_acflags & af_dyninside) != 0)
         }
       }
 
-    show_brack_acc(US"\302\206", fontsize, x + out_dynmovex[dyn_ring],
+    show_brack_acc(US"\302\206", fontsize, xn + out_dynmovex[dyn_ring],
       out_ystave - p - 4*main_stavemagn + yy - out_dynmovey[dyn_ring],
       out_dynmovef[dyn_ring],
       acc_upflag? 4*main_stavemagn:(-4)*main_stavemagn,
@@ -933,7 +979,7 @@ if ((n_acflags & af_dyninside) != 0)
 
   if ((n_acflags & af_bar) != 0)
     {
-    show_brack_acc(US"T", fontsize, x + out_dynmovex[dyn_bar],
+    show_brack_acc(US"T", fontsize, xn + out_dynmovex[dyn_bar],
       out_ystave - p - out_dynmovey[dyn_bar], out_dynmovef[dyn_bar],
       acc_upflag? 4*main_stavemagn:-4*main_stavemagn, -4*main_stavemagn,
       2*main_stavemagn, 2*main_stavemagn);
@@ -1093,10 +1139,10 @@ if (n_ornament != NULL)
         if (matrix != NULL) memcpy(font_transform, matrix, 4*sizeof(int));
         out_string(curmovt->trillstring, font_it, tsize, x,
           out_ystave - mac_muldiv(y, main_stavemagn, 1000), 0);
-          
+
         /* For a bracketed trill, use the show_brack_acc() function with
         an empty string. */
-          
+
         if (n_ornament->bflags != 0)
           show_brack_acc(US"", size, x,
             out_ystave - mac_muldiv(y, main_stavemagn, 1000),
@@ -1106,7 +1152,7 @@ if (n_ornament != NULL)
                    ornament_yaadjusts[ornament],
             ornament_xbrackadjustsL[ornament],
             ornament_xbrackadjustsR[ornament]);
- 
+
         font_reset();
         size = asize;
         if (below) y -= asize;
