@@ -2,10 +2,10 @@
 *    The PMS Music Typesetter - 2nd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2009 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: January 2009 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains code for reading and processing strings. */
@@ -57,6 +57,7 @@ static esctabstr esctab[] = {
   { ('C' << 8) + '\'',   0x0106 },  /* Cacute */
   { ('C' << 8) + ')',    0x00a9 },  /* Copyright */
   { ('C' << 8) + ',',    0x00c7 },  /* Ccedilla */
+  { ('C' << 8) + '@',    0x0108 },  /* Ccircumflex */ 
   { ('C' << 8) + 'v',    0x010c },  /* Ccaron */
 
   { ('D' << 8) + '-',    0x0110 },  /* Dcroat */
@@ -67,15 +68,23 @@ static esctabstr esctab[] = {
   { ('E' << 8) + '.',    0x00cb },  /* Edieresis */
   { ('E' << 8) + '@',    0x00ca },  /* Ecircumflex */
   { ('E' << 8) + '`',    0x00c8 },  /* Egrave */
+  { ('E' << 8) + 'u',    0x0114 },  /* Ebreve */
   { ('E' << 8) + 'v',    0x011a },  /* Ecaron */
 
+  { ('G' << 8) + '@',    0x011c },  /* Gcircumflex */ 
   { ('G' << 8) + 'u',    0x011e },  /* Gbreve */
 
+  { ('H' << 8) + '@',    0x0124 },  /* Hcircumflex */ 
+
   { ('I' << 8) + '\'',   0x00cd },  /* Iacute */
   { ('I' << 8) + '-',    0x012a },  /* Imacron */
   { ('I' << 8) + '.',    0x00cf },  /* Idieresis */
   { ('I' << 8) + '@',    0x00ce },  /* Icircumflex */
   { ('I' << 8) + '`',    0x00cc },  /* Igrave */
+  { ('I' << 8) + 'u',    0x012C },  /* Ibreve */
+  { ('I' << 8) + '~',    0x0128 },  /* Itilde */
+
+  { ('J' << 8) + '@',    0x0134 },  /* Jcircumflex */ 
 
   { ('L' << 8) + '\'',   0x0139 },  /* Lacute */
   { ('L' << 8) + '/',    0x0141 },  /* Lslash */
@@ -91,6 +100,7 @@ static esctabstr esctab[] = {
   { ('O' << 8) + '/',    0x00d8 },  /* Oslash */
   { ('O' << 8) + '@',    0x00d4 },  /* Ocircumflex */
   { ('O' << 8) + '`',    0x00d2 },  /* Ograve */
+  { ('O' << 8) + 'u',    0x014e },  /* Obreve */
   { ('O' << 8) + '~',    0x00d5 },  /* Otilde */
 
   { ('R' << 8) + '\'',   0x0154 },  /* Racute */
@@ -98,8 +108,10 @@ static esctabstr esctab[] = {
 
   { ('S' << 8) + '\'',   0x015a },  /* Sacute */
   { ('S' << 8) + ',',    0x015e },  /* Scedilla */
+  { ('S' << 8) + '@',    0x015c },  /* Scircumflex */ 
   { ('S' << 8) + 'v',    0x0160 },  /* Scaron */
 
+  { ('T' << 8) + ',',    0x0162 },  /* Tcedilla */
   { ('T' << 8) + 'v',    0x0164 },  /* Tcaron */
 
   { ('U' << 8) + '\'',   0x00da },  /* Uacute */
@@ -108,9 +120,14 @@ static esctabstr esctab[] = {
   { ('U' << 8) + '@',    0x00db },  /* Ucircumflex */
   { ('U' << 8) + '`',    0x00d9 },  /* Ugrave */
   { ('U' << 8) + 'o',    0x016e },  /* Uring */
+  { ('U' << 8) + 'u',    0x016c },  /* Ubreve */
+  { ('U' << 8) + '~',    0x0168 },  /* Utilde */
+
+  { ('W' << 8) + '@',    0x0174 },  /* Wcircumflex */ 
 
   { ('Y' << 8) + '\'',   0x00dd },  /* Yacute */
   { ('Y' << 8) + '.',    0x0178 },  /* Ydieresis */
+  { ('Y' << 8) + '@',    0x0176 },  /* Ycircumflex */ 
 
   { ('Z' << 8) + '\'',   0x0179 },  /* Zacute */
   { ('Z' << 8) + 'v',    0x017d },  /* Zcaron */
@@ -127,6 +144,7 @@ static esctabstr esctab[] = {
   { ('c' << 8) + '\'',   0x0107 },  /* cacute */
   { ('c' << 8) + ')',    0x00a9 },  /* copyright */
   { ('c' << 8) + ',',    0x00e7 },  /* ccedilla */
+  { ('c' << 8) + '@',    0x0109 },  /* ccircumflex */ 
   { ('c' << 8) + 'v',    0x010d },  /* ccaron */
 
   { ('d' << 8) + '-',    0x0111 },  /* dcroat */
@@ -137,15 +155,23 @@ static esctabstr esctab[] = {
   { ('e' << 8) + '.',    0x00eb },  /* edieresis */
   { ('e' << 8) + '@',    0x00ea },  /* ecircumflex */
   { ('e' << 8) + '`',    0x00e8 },  /* egrave */
+  { ('e' << 8) + 'u',    0x0115 },  /* ebreve */
   { ('e' << 8) + 'v',    0x011b },  /* ecaron */
 
+  { ('g' << 8) + '@',    0x011d },  /* gcircumflex */ 
   { ('g' << 8) + 'u',    0x011f },  /* gbreve */
 
+  { ('h' << 8) + '@',    0x0125 },  /* hcircumflex */ 
+
   { ('i' << 8) + '\'',   0x00ed },  /* iacute */
   { ('i' << 8) + '-',    0x012b },  /* imacron */
   { ('i' << 8) + '.',    0x00ef },  /* idieresis */
   { ('i' << 8) + '@',    0x00ee },  /* icircumflex */
   { ('i' << 8) + '`',    0x00ec },  /* igrave */
+  { ('i' << 8) + 'u',    0x012d },  /* ibreve */
+  { ('i' << 8) + '~',    0x0129 },  /* itilde */
+
+  { ('j' << 8) + '@',    0x0135 },  /* jcircumflex */ 
 
   { ('l' << 8) + '\'',   0x013a },  /* Lacute */
   { ('l' << 8) + '/',    0x0142 },  /* Lslash */
@@ -161,6 +187,7 @@ static esctabstr esctab[] = {
   { ('o' << 8) + '/',    0x00f8 },  /* oslash */
   { ('o' << 8) + '@',    0x00f4 },  /* ocircumflex */
   { ('o' << 8) + '`',    0x00f2 },  /* ograve */
+  { ('o' << 8) + 'u',    0x014f },  /* obreve */
   { ('o' << 8) + '~',    0x00f5 },  /* otilde */
 
   { ('r' << 8) + '\'',   0x0155 },  /* racute */
@@ -168,8 +195,10 @@ static esctabstr esctab[] = {
 
   { ('s' << 8) + '\'',   0x015b },  /* sacute */
   { ('s' << 8) + ',',    0x015f },  /* scedilla */
+  { ('s' << 8) + '@',    0x015d },  /* scircumflex */ 
   { ('s' << 8) + 'v',    0x0161 },  /* scaron */
 
+  { ('t' << 8) + ',',    0x0163 },  /* tcedilla */
   { ('t' << 8) + 'v',    0x0165 },  /* tcaron */
 
   { ('u' << 8) + '\'',   0x00fa },  /* uacute */
@@ -178,9 +207,14 @@ static esctabstr esctab[] = {
   { ('u' << 8) + '@',    0x00fb },  /* ucircumflex */
   { ('u' << 8) + '`',    0x00f9 },  /* ugrave */
   { ('u' << 8) + 'o',    0x016f },  /* uring */
+  { ('u' << 8) + 'u',    0x016d },  /* ubreve */
+  { ('u' << 8) + '~',    0x0169 },  /* utilde */
+
+  { ('w' << 8) + '@',    0x0175 },  /* wcircumflex */ 
 
   { ('y' << 8) + '\'',   0x00fd },  /* yacute */
   { ('y' << 8) + '.',    0x00ff },  /* ydieresis */
+  { ('y' << 8) + '@',    0x0177 },  /* ycircumflex */ 
 
   { ('z' << 8) + '\'',   0x017a },  /* zacute */
   { ('z' << 8) + 'v',    0x017e },  /* zcaron */
@@ -794,13 +828,16 @@ else switch (*s)
   case 'd':
   case 'e':
   case 'g':
+  case 'h': 
   case 'i':
+  case 'j': 
   case 'l':
   case 'n':
   case 'o':
   case 'r':
   case 't':
   case 'u':
+  case 'w': 
   case 'y':
   case 'z':
   case 'A':
@@ -808,6 +845,8 @@ else switch (*s)
   case 'D':
   case 'E':
   case 'G':
+  case 'H':
+  case 'J':  
   case 'I':
   case 'L':
   case 'N':
@@ -816,6 +855,7 @@ else switch (*s)
   case 'S':
   case 'T':
   case 'U':
+  case 'W': 
   case 'Y':
   case 'Z':
 
@@ -931,7 +971,6 @@ Returns:   nothing
 void
 string_stavestring(BOOL rehearse)
 {
-b_textstr *p;
 BOOL hadab = FALSE;
 int rotate = 0;
 int halfway = 0;
@@ -1293,6 +1332,7 @@ preceded by an extras block if required. */
 
 if ((flags & text_ul) == 0)
   {
+  b_textstr *p;
   if (rotate || halfway)
     {
     b_textXstr *pp = store_getitem(b_textX);
