@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2013 */
+/* Copyright (c) Philip Hazel, 1991 - 2016 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: March 2013 */
+/* This file last modified: June 2016 */
 
 
 /* This file contains all the major tables used by the program; a few that are
@@ -50,15 +50,15 @@ const uschar utf8_table4[] = {
 *               Miscellaneous                    *
 *************************************************/
 
-int main_bit[] = {
- 0x00000001, 0x00000002, 0x00000004, 0x00000008,
- 0x00000010, 0x00000020, 0x00000040, 0x00000080,
- 0x00000100, 0x00000200, 0x00000400, 0x00000800,
- 0x00001000, 0x00002000, 0x00004000, 0x00008000,
- 0x00010000, 0x00020000, 0x00040000, 0x00080000,
- 0x00100000, 0x00200000, 0x00400000, 0x00800000,
- 0x01000000, 0x02000000, 0x04000000, 0x08000000,
- 0x10000000, 0x20000000, 0x40000000, 0x80000000};
+unsigned int main_bit[] = {
+ 0x00000001u, 0x00000002u, 0x00000004u, 0x00000008u,
+ 0x00000010u, 0x00000020u, 0x00000040u, 0x00000080u,
+ 0x00000100u, 0x00000200u, 0x00000400u, 0x00000800u,
+ 0x00001000u, 0x00002000u, 0x00004000u, 0x00008000u,
+ 0x00010000u, 0x00020000u, 0x00040000u, 0x00080000u,
+ 0x00100000u, 0x00200000u, 0x00400000u, 0x00800000u,
+ 0x01000000u, 0x02000000u, 0x04000000u, 0x08000000u,
+ 0x10000000u, 0x20000000u, 0x40000000u, 0x80000000u};
 
 
 /* Font identification strings. This table must be lengthened if more than 12
